import * as CSS from 'csstype';
import { FileTypeResult } from 'file-type';
import { FormatEnum, ColourspaceEnum, Channels, LevelMetadata } from 'sharp';

interface Language {
    baseName: string;
    language: string;
    region?: string;
    nativeName: string;
}
interface ILanguageMap {
    'ar-SA': Language;
    'bn-BD': Language;
    'en-US': Language;
    'de-DE': Language;
    'el-GR': Language;
    'es-ES': Language;
    'fi-FI': Language;
    'fil-PH': Language;
    'fr-FR': Language;
    'hi-IN': Language;
    'hu-HU': Language;
    'id-ID': Language;
    'it-IT': Language;
    'ja-JP': Language;
    'ko-KR': Language;
    'nl-NL': Language;
    'pl-PL': Language;
    'pt-BR': Language;
    'pt-PT': Language;
    'ro-RO': Language;
    'ru-RU': Language;
    'sv-SE': Language;
    'ta-IN': Language;
    'tr-TR': Language;
    'uk-UA': Language;
    'vi-VN': Language;
    'zh-CN': Language;
    'zh-TW': Language;
}
declare class LanguageMap implements ILanguageMap {
    'ar-SA': Language;
    'bn-BD': Language;
    'en-US': Language;
    'de-DE': Language;
    'el-GR': Language;
    'es-ES': Language;
    'fi-FI': Language;
    'fil-PH': Language;
    'fr-FR': Language;
    'hi-IN': Language;
    'hu-HU': Language;
    'id-ID': Language;
    'it-IT': Language;
    'ja-JP': Language;
    'ko-KR': Language;
    'nl-NL': Language;
    'pl-PL': Language;
    'pt-BR': Language;
    'pt-PT': Language;
    'ro-RO': Language;
    'ru-RU': Language;
    'sv-SE': Language;
    'ta-IN': Language;
    'tr-TR': Language;
    'uk-UA': Language;
    'vi-VN': Language;
    'zh-CN': Language;
    'zh-TW': Language;
}
type LanguageCode = keyof ILanguageMap;
type LanguageTextMap = {
    [key in LanguageCode]?: string;
};

declare class ElectronApi {
    static addIpcListener(key: string, f: Function): Promise<void>;
    static removeIpcListener(key: string): Promise<void>;
}

interface IWidgetTheme {
    /**
     * 是否使用全局主题，
     * 默认true
     */
    useGlobalTheme?: boolean;
    borderRadius?: CSS.Properties['borderRadius'];
    backgroundColor?: CSS.Properties['color'];
    /**
     * 背景边框颜色
     */
    backgroundBorderColor?: CSS.Properties['color'];
    backgroundBoxShadowColor?: CSS.Properties['color'];
    fontSize?: CSS.Properties['fontSize'];
    dividerColor?: CSS.Properties['color'];
    /**
     * 主色调
     */
    primaryColor?: CSS.Properties['color'];
    /**
     * 文字颜色
     */
    color?: CSS.Properties['color'];
    fontFamily?: CSS.Properties['fontFamily'];
    shadowColor?: CSS.Properties['color'];
    padding?: CSS.Properties['padding'];
    borderColor?: CSS.Properties['borderColor'];
}
type WidgetThemeProperty = keyof IWidgetTheme;
declare class WidgetTheme implements IWidgetTheme {
    borderRadius?: CSS.Properties['borderRadius'];
    backgroundColor?: CSS.Properties['color'];
    fontSize?: CSS.Properties['fontSize'];
    dividerColor?: CSS.Properties['color'];
    /**
     * 主色调
     */
    primaryColor?: CSS.Properties['color'];
    backgroundBorderColor?: CSS.Properties['color'];
    backgroundBoxShadowColor?: CSS.Properties['color'];
    /**
     * 文字颜色
     */
    color?: CSS.Properties['color'];
    fontFamily?: CSS.Properties['fontFamily'];
    shadowColor?: CSS.Properties['color'];
    padding?: CSS.Properties['padding'];
    borderColor?: CSS.Properties['borderColor'];
    useGlobalTheme?: boolean;
    constructor(options?: IWidgetTheme | string);
    static fromJSON(json: string): WidgetTheme;
    /**
     * Injects the style properties as css variable.
     * @param selector default is 'body'
     */
    toCSS(selector?: string): string;
    /**
     * Injects the style properties as css variable.
     * @param rootElement The rootElement to inject the css.
     * @remarks Only works in a browser environment.
     */
    injectCSS(rootElement?: HTMLElement): void;
    removeCSS(rootElement?: HTMLElement): void;
    copy(options?: IWidgetTheme): WidgetTheme;
    /**
     * Gets the style properties from the widget's style object.
     * @returns A record representing CSS custom variable and their values.
     */
    toCSSVariable(): Record<string, string>;
    toCSSProperties(): Record<string, string>;
    static fromCSS(css: string): WidgetTheme;
}
type WidgetThemeKey = keyof WidgetTheme;
/**
 * Widget default theme, this object is immutable. Clone it before use.
 */
declare const DefaultWidgetTheme: WidgetTheme;

/**
 * 组件配置数据，用于存储组件自定义页面所设置的数据
 * @deprecated
 */
declare class WidgetData {
    /**
     * 组件id
     */
    id?: string;
    /**
     * 组件名
     */
    name: string;
    /**
     * 背景颜色
     * @deprecated
     */
    backgroundColor?: string;
    /**
     * 文字颜色
     * @deprecated
     */
    color?: string;
    /**
     * 字体大小
     * @deprecated
     */
    fontSize?: number;
    /**
     * 字体
     * @deprecated
     */
    fontFamily?: string;
    /**
     * 圆角半径
     * @deprecated
     */
    borderRadius?: number;
    /**
     * 组件样式
     * @deprecated
     */
    theme: WidgetTheme;
    constructor(name: string, id?: string);
    parseJSON(json: any): void;
    /**
     * Gets the style properties from the widget's style object.
     * @returns A record representing CSS custom properties and their values.
     */
    getThemeProperties(): Record<string, string>;
    /**
     * Injects the style properties as css variable.
     * @remarks Only works in a browser environment.
     */
    injectThemeProperties(): void;
}

interface SaveWidgetOption {
    sendBroadcast?: boolean;
    id?: string;
    storeName?: string;
}
/**
 * 用户处理浏览器数据，只在浏览器环境下有用
 * @deprecated
 */
interface IWidgetDataApi {
    findByName: (<T extends WidgetData>(name: string, type: {
        new (name: string, id?: string): T;
    }) => Promise<T | undefined>) & (<T extends WidgetData>(data: T) => Promise<T | undefined>);
    save: (data: WidgetData, options?: SaveWidgetOption) => Promise<string>;
    /**
     * 获取组件 LocalForage 存储实例
     * @param widgetName  组件名
     * @param storeName   存储名
     * @see https://localforage.docschina.org/
     */
    getStore: (widgetName: string, storeName?: string) => LocalForage;
    saveByName: <T extends WidgetData>(data: T, options?: SaveWidgetOption) => Promise<string>;
    find: <T extends WidgetData>(name: string, id: string, type: {
        new (name: string, id?: string): T;
    }) => Promise<T | undefined>;
}
type WidgetDataApiMethods = keyof IWidgetDataApi;
declare const WidgetDataApi: IWidgetDataApi;

/**
 * 设置窗口位置的选项
 */
interface BrowserWindowOptions {
    /**
     * 分区
     * @deprecated
     */
    partition?: string;
    /**
     * 是否使用外部浏览器打开
     */
    external?: boolean;
    /**
     * Window's width in pixels. Default is `800`.
     */
    width?: number;
    /**
     * Window's height in pixels. Default is `600`.
     */
    height?: number;
    /**
     * (**required** if y is used) Window's left offset from screen. Default is to
     * center the window.
     */
    x?: number;
    /**
     * (**required** if x is used) Window's top offset from screen. Default is to
     * center the window.
     */
    y?: number;
    /**
     * Show window in the center of the screen. Default is `false`.
     */
    center?: boolean;
    /**
     * Window's minimum width. Default is `0`.
     */
    minWidth?: number;
    /**
     * Window's minimum height. Default is `0`.
     */
    minHeight?: number;
    /**
     * Window's maximum width. Default is no limit.
     */
    maxWidth?: number;
    /**
     * Window's maximum height. Default is no limit.
     */
    maxHeight?: number;
    /**
     * Whether window is resizable. Default is `true`.
     */
    resizable?: boolean;
    /**
     * Whether window is movable. This is not implemented on Linux. Default is `true`.
     *
     * @platform darwin,win32
     */
    movable?: boolean;
    /**
     * Whether window is minimizable. This is not implemented on Linux. Default is
     * `true`.
     *
     * @platform darwin,win32
     */
    minimizable?: boolean;
    /**
     * Whether window is maximizable. This is not implemented on Linux. Default is
     * `true`.
     *
     * @platform darwin,win32
     */
    maximizable?: boolean;
    /**
     * Whether window is closable. This is not implemented on Linux. Default is `true`.
     *
     * @platform darwin,win32
     */
    closable?: boolean;
    /**
     * Whether the window should always stay on top of other windows. Default is
     * `false`.
     */
    alwaysOnTop?: boolean;
    /**
     * Whether to show the window in taskbar. Default is `false`.
     *
     * @platform darwin,win32
     */
    skipTaskbar?: boolean;
    /**
     * The window's background color in Hex, RGB, RGBA, HSL, HSLA or named CSS color
     * format. Alpha in #AARRGGBB format is supported if `transparent` is set to
     * `true`. Default is `#FFF` (white). See win.setBackgroundColor for more
     * information.
     */
    backgroundColor?: string;
    /**
     * Whether window should have a shadow. Default is `true`.
     */
    hasShadow?: boolean;
    /**
     * Set the initial opacity of the window, between 0.0 (fully transparent) and 1.0
     * (fully opaque). This is only implemented on Windows and macOS.
     *
     * @platform darwin,win32
     */
    opacity?: number;
    /**
     * Makes the window transparent. Default is `false`. On Windows, does not work
     * unless the window is frameless.
     */
    transparent?: boolean;
    /**
     * The style of window title bar. Default is `default`. Possible values are:
     *
     * @platform darwin,win32
     */
    titleBarStyle?: ('default' | 'hidden' | 'hiddenInset' | 'customButtonsOnHover');
    /**
     * Use `WS_THICKFRAME` style for frameless windows on Windows, which adds standard
     * window frame. Setting it to `false` will remove window shadow and window
     * animations. Default is `true`.
     */
    thickFrame?: boolean;
    /**
     * Enables image support. Default is `true`.
     */
    images?: boolean;
    /**
     * Whether to enable offscreen rendering for the browser window. Defaults to
     * `false`. See the offscreen rendering tutorial for more details.
     */
    offscreen?: boolean;
    /**
     * Whether to enable the `<webview>` tag. Defaults to `false`. **Note:** The
     * `preload` script configured for the `<webview>` will have node integration
     * enabled when it is executed so you should ensure remote/untrusted content is not
     * able to create a `<webview>` tag with a possibly malicious `preload` script. You
     * can use the `will-attach-webview` event on webContents to strip away the
     * `preload` script and to validate or alter the `<webview>`'s initial settings.
     */
    webviewTag?: boolean;
    backgroundThrottling?: boolean;
    frame?: boolean;
    backgroundMaterial?: ('auto' | 'none' | 'mica' | 'acrylic' | 'tabbed');
}

/**
 * @see [Rectangle](https://electronjs.org/docs/api/structures/rectangle)
 */
interface Rectangle {
    /**
     * The height of the rectangle (must be an integer).
     */
    height: number;
    /**
     * The width of the rectangle (must be an integer).
     */
    width: number;
    /**
     * The x coordinate of the origin of the rectangle (must be an integer).
     */
    x: number;
    /**
     * The y coordinate of the origin of the rectangle (must be an integer).
     */
    y: number;
}

interface ProxyConfig {
    /**
     * The proxy mode. Should be one of `direct`, `auto_detect`, `pac_script`,
     * `fixed_servers` or `system`. If it's unspecified, it will be automatically
     * determined based on other specified options.
     */
    mode?: ('direct' | 'auto_detect' | 'pac_script' | 'fixed_servers' | 'system');
    /**
     * The URL associated with the PAC file.
     */
    pacScript?: string;
    /**
     * Rules indicating which proxies to use.
     */
    proxyRules?: string;
    /**
     * Rules indicating which URLs should bypass the proxy settings.
     */
    proxyBypassRules?: string;
}

interface Position {
    x: number;
    y: number;
}

interface Point {
    x: number;
    y: number;
}

declare enum Gravity {
    TOP = "TOP",
    LEFT = "LEFT",
    RIGHT = "RIGHT",
    BOTTOM = "BOTTOM"
}

interface AppRuntimeInfo {
    node: string;
    app: string;
    electron: string;
    chrome: string;
    v8: string;
    appPath: string;
    isWindowsStore: boolean;
    /**
     * @example win32
     */
    platform: string;
    /**
     * @example x64
     */
    arch: string;
    /**
     * @example 10.0.22631
     */
    release: string;
    /**
     * @example Intel(R) Core(TM) i7-8700K CPU @ 3.70GHz
     */
    cpuModel: string;
    totalMem: number;
    /**
     * @example windows 10
     */
    systemName: string;
}

declare abstract class BaseApi<T extends string> {
    abstract getChannel(): string;
    protected invokeMethod(method: T, ...args: any[]): Promise<any>;
    protected invoke(...args: any[]): Promise<any>;
}

/**
 * BrowserWindowApi 接口定义了一系列用于控制窗口的方法，这些方法提供了窗口的显示、隐藏、移动、调整大小等功能
 * @remarks 注意：桌面类型组件不支持窗口移动、调整大小、最大化、最小化等操作
 */
interface IBrowserWindowApi {
    /**
     * 设置是否忽略鼠标事件
     * @param ignore boolean
     */
    setIgnoreMouseEvent: (ignore: boolean) => Promise<void>;
    /**
     * 显示窗口
     */
    show: () => Promise<void>;
    /**
     * 设置窗口是否有阴影
     * @param hasShadow boolean
     */
    setHasShadow: (hasShadow: boolean) => Promise<void>;
    /**
     * 隐藏窗口
     */
    hide: () => Promise<void>;
    /**
     * 关闭窗口
     */
    close: () => Promise<void>;
    /**
     * 以不激活窗口的方式显示窗口
     */
    showInactive: () => Promise<void>;
    /**
     * 将窗口居中
     */
    center: () => Promise<void>;
    /**
     * 开始拖动窗口
     */
    startDraggingWindow: () => Promise<void>;
    /**
     * 最小化窗口
     */
    minimize: () => Promise<void>;
    /**
     * 还原窗口
     */
    restore: () => Promise<void>;
    /**
     * 窗口是否最小后
     * @return  Promise<boolean>
     */
    isMinimized: () => Promise<boolean>;
    /**
     * 检查窗口是否最大化
     * @return  Promise<boolean>
     */
    isMaximized: () => Promise<boolean>;
    /**
     * 检查窗口是否可见
     * @return  Promise<boolean>
     */
    isVisible: () => Promise<boolean>;
    /**
     * 检查窗口是否可调整大小
     * @since 24.1.1-beta.6
     * @return  Promise<boolean>
     */
    isResizable: () => Promise<boolean>;
    /**
     * 最大化窗口
     */
    maximize: () => Promise<void>;
    /**
     * 停止拖动窗口
     */
    stopDraggingWindow: () => Promise<void>;
    /**
     * 检查窗口是否正在拖动
     * @return  Promise<boolean>
     */
    isDraggingWindow: () => Promise<boolean>;
    /**
     * 设置窗口是否总在最前
     * @param alwaysOnTop boolean
     */
    setAlwaysOnTop: (alwaysOnTop: boolean) => Promise<void>;
    /**
     * 检查窗口是否总在最前
     * @return  Promise<boolean>
     */
    isAlwaysOnTop: () => Promise<boolean>;
    /**
     * 打开指定的 URL
     * @param url string 要打开的 URL
     * @param option OpenUrlOptions - 可选参数，用于配置 URL 打开的方式
     */
    openUrl: (url: string, option?: BrowserWindowOptions) => Promise<void>;
    /**
     * 将窗口置于最前
     */
    moveTop: () => Promise<void>;
    /**
     * 取消最大化窗口
     */
    unmaximize: () => Promise<void>;
    /**
     * 重新加载窗口
     */
    reload: () => Promise<void>;
    /**
     * 设置窗口大小
     * @param width boolean - 窗口宽度
     * @param height boolean - 窗口高度
     * @param animate boolean - 是否使用动画（可选）
     */
    setSize: (width: number, height: number, animate?: boolean) => Promise<void>;
    /**
     * 获取窗口大小
     * @since 24.1.1-beta.6
     * @returns Promise<number[]>
     */
    getSize: () => Promise<number[]>;
    /**
     * 打开开发者工具
     */
    openDevTools: () => Promise<void>;
    /**
     * 设置窗口位置
     * @param {SetPositionOptions} options - 配置窗口位置的选项
     */
    setPosition: (options: SetPositionOptions) => Promise<void>;
    /**
     * 获取窗口位置
     * @returns {Promise<Position>} 返回一个 Promise，解析为窗口的位置
     */
    getPosition: () => Promise<Position>;
    /**
     * 使窗口失去焦点
     */
    blur: () => Promise<void>;
    /**
     * 聚焦窗口
     */
    focus: () => Promise<void>;
    /**
     * 设置窗口是否可调整大小
     * @param resizable boolean - 是否可调整大小
     */
    setResizable: (resizable: boolean) => Promise<void>;
    /**
     * 设置窗口是否可移动
     * @param movable boolean - 是否可移动
     */
    setMovable: (movable: boolean) => Promise<void>;
    /**
     * 获取窗口边界
     * @returns Promise<Rectangle>
     */
    getBounds: () => Promise<Rectangle>;
    /**
     * 设置窗口边界
     * @param {Partial<Rectangle>} bounds - 窗口的边界矩形
     * @param {boolean} animate - 是否启用动画
     */
    setBounds: (bounds: Partial<Rectangle>, animate: boolean) => Promise<void>;
    /**
     * 将窗口对齐到当前屏幕
     * @param align string 对齐位置
     *  <ol>
     *    <li>'top-left'</li>
     *    <li>'top-center'</li>
     *    <li>'top-right'</li>
     *    <li>'bottom-left'</li>
     *    <li>'bottom-center'</li>
     *    <li>'bottom-right'</li>
     *    </ol>
     */
    alignToScreen: (align: AlignPosition) => Promise<void>;
    /**
     * 检查指定 URL 是否存在
     * @param {string} url - 要检查的 URL
     * @return  Promise<boolean>
     */
    existsByUrl: (url: string) => Promise<boolean>;
    /**
     * 获取窗口的最大尺寸
     * @returns {Promise<number[]>} 返回一个 Promise，解析为一个数组，包含窗口的最大宽度和高度
     */
    getMaximumSize: () => Promise<number[]>;
    /**
     * 获取窗口的最小尺寸
     * @returns {Promise<number[]>} 返回一个 Promise，解析为一个数组，包含窗口的最小宽度和高度
     */
    getMinimumSize: () => Promise<number[]>;
    /**
     * 设置窗口的最大尺寸
     * @param {number} width - 最大宽度
     * @param {number} height - 最大高度
     */
    setMaximumSize: (width: number, height: number) => Promise<void>;
    /**
     * 设置窗口的最小尺寸
     * @param {number} width - 最大宽度
     * @param {number} height - 最大高度
     */
    setMinimumSize: (width: number, height: number) => Promise<void>;
    /**
     * 更改缩放等级 原始尺寸为 0，每升高或将顶代表缩放20%，大和小限制默认分区为 300% 和 50% 缩放公式为 scale := 1.2 ^ level.
     * @param level number - 缩放等级，默认为 0
     */
    setZoomLevel: (level: number) => Promise<void>;
    /**
     * 更改缩放倍数 缩放系数是缩放百分比除以 100，即 300% = 3.0
     * @param factor Double - 缩放系数，默认为 1.0
     * @remarks 系数必须大于0.0
     */
    setZoomFactor: (factor: number) => Promise<void>;
    /**
     * 设置窗口网络代理，设置后所有链接都会断开，最好重新刷新下页面(window.location.reload())
     * @param config
     * @example
     * ```typescript
     * BrowserWindowApi.setProxy({
     *     proxyRules:'socks5://127.0.0.1:7890'
     * })
     * ```
     */
    setProxy: (config: ProxyConfig) => Promise<void>;
    /**
     * @return Promise<boolean>
     */
    isFocused: () => Promise<boolean>;
    /**
     * A top-level window created with this style does not become the foreground window when the user clicks it. The system does not bring this window to the foreground when the user minimizes or closes the foreground window.
     * The window should not be activated through programmatic access or via keyboard navigation by accessible technology, such as Narrator.
     * @see [Extended Window Styles](https://learn.microsoft.com/en-us/windows/win32/winmsg/extended-window-styles)
     */
    setNoActivate: () => Promise<void>;
    /**
     * Controls whether or not this window's WebContents will throttle animations and timers when the page becomes backgrounded. This also affects the Page Visibility API.
     * @param enabled
     * @see https://www.electronjs.org/docs/latest/api/web-contents#contentssetbackgroundthrottlingallowed
     */
    setBackgroundThrottling: (enabled: boolean) => Promise<void>;
    getBackgroundThrottling: () => Promise<boolean>;
}

type BrowserWindowApiMethods = keyof IBrowserWindowApi;
type AlignPosition = 'top-left' | 'top-center' | 'top-right' | 'bottom-left' | 'bottom-center' | 'bottom-right';
interface SetPositionOptions {
    x?: number;
    y?: number;
    /**
     * 只有在 macOS 上有效
     */
    animation?: boolean;
}
declare enum BrowserWindowApiEvent {
    BLUR = "event::cn.widgetjs.core.browser-window.blur",
    MOVED = "event::cn.widgetjs.core.browser-window.moved",
    FOCUS = "event::cn.widgetjs.core.browser-window.focus",
    SNAP_TO_EDGE = "event::cn.widgetjs.core.browser-window.snap_to_edge",
    RESIZED = "event::cn.widgetjs.core.browser-window.resized",
    CANCEL_SNAP_TO_EDGE = "event::cn.widgetjs.core.browser-window.cancel_snap_to_edge"
}
interface SetupOptions {
    width: number;
    height: number;
    minWidth?: number;
    minHeight?: number;
    maxWidth?: number;
    maxHeight?: number;
    resizable?: boolean;
    movable?: boolean;
    center?: boolean;
    alwaysOnTop?: boolean;
    x?: number;
    y?: number;
}
declare class BrowserWindowApiImpl extends BaseApi<BrowserWindowApiMethods> implements IBrowserWindowApi {
    setBackgroundThrottling(enabled: boolean): Promise<void>;
    getBackgroundThrottling(): Promise<boolean>;
    isResizable(): Promise<boolean>;
    setHasShadow(hasShadow: boolean): Promise<void>;
    isDraggingWindow(): Promise<boolean>;
    setNoActivate(): Promise<void>;
    isVisible(): Promise<boolean>;
    getChannel(): string;
    setIgnoreMouseEvent(ignore: boolean): Promise<void>;
    show(): Promise<void>;
    showInactive(): Promise<void>;
    hide(): Promise<void>;
    center(): Promise<void>;
    setAlwaysOnTop(alwaysOnTop: boolean): Promise<void>;
    isAlwaysOnTop(): Promise<boolean>;
    openUrl(url: string, option?: BrowserWindowOptions): Promise<void>;
    moveTop(): Promise<void>;
    openDevTools(): Promise<void>;
    setPosition(options: SetPositionOptions): Promise<void>;
    getPosition(): Promise<Position>;
    blur(): Promise<any>;
    focus(): Promise<any>;
    /**
     * 设置窗口是否可以拉伸
     * @param resizable
     */
    setResizable(resizable: boolean): Promise<any>;
    getBounds(): Promise<Rectangle>;
    setBounds(bounds: Partial<Rectangle>, animate?: boolean): Promise<void>;
    alignToScreen(align: AlignPosition): Promise<any>;
    startDraggingWindow(): Promise<any>;
    stopDraggingWindow(): Promise<any>;
    /**
     * 通过url检测窗口是否存在
     * @param url
     */
    existsByUrl(url: string): Promise<boolean>;
    getMaximumSize(): Promise<number[]>;
    minimize(): Promise<void>;
    maximize(): Promise<void>;
    isMaximized(): Promise<boolean>;
    isMinimized(): Promise<boolean>;
    restore(): Promise<void>;
    unmaximize(): Promise<void>;
    setZoomLevel(level: number): Promise<void>;
    reload(): Promise<void>;
    setMovable(movable: boolean): Promise<void>;
    setSize(width: number, height: number, animate?: boolean): Promise<void>;
    isFocused(): Promise<boolean>;
    setMaximumSize(width: number, height: number): Promise<void>;
    setMinimumSize(width: number, height: number): Promise<void>;
    getMinimumSize(): Promise<number[]>;
    close(): Promise<void>;
    setZoomFactor(factor: number): Promise<void>;
    setup(options: SetupOptions): Promise<void>;
    setProxy(config: Electron.Config): Promise<void>;
    getSize(): Promise<number[]>;
}
declare const BrowserWindowApi: BrowserWindowApiImpl;

type NotificationType = 'countdown' | 'advance-countdown' | 'error' | 'success' | 'warning' | 'info' | 'reminder' | 'url' | 'call';
declare enum NotificationSize {
    SMALL = "small",
    NORMAL = "normal",
    LARGE = "large"
}
interface CountdownNotificationOption extends InfoNotificationOption {
    targetTime?: string;
}
interface InfoNotificationOption {
    message: string;
    duration?: number;
    /**
     * 图片名，目前只支持mingcute图标。
     * https://www.mingcute.com/
     */
    icon?: string;
    color?: string;
    size?: NotificationSize;
    backgroundColor?: string;
}
interface CallNotificationOption extends InfoNotificationOption {
    lyric?: string;
    audio?: string;
    avatar?: string;
}
interface ReminderNotificationOption extends InfoNotificationOption {
    confirmButtonText?: string;
    cancelButtonText?: string;
    title?: string;
    cancelBroadcast?: string;
    confirmBroadcast?: string;
}
interface NotificationOption extends InfoNotificationOption, ReminderNotificationOption, CountdownNotificationOption, CallNotificationOption {
    type?: NotificationType;
}
declare class AppNotification {
    type: NotificationType;
    message: string;
    title?: string;
    targetTime?: string;
    /**
     * 持续时间，单位毫秒
     */
    duration: number;
    /**
     * IconPark图标
     * @example close-one
     * @see [IconPark](https://iconpark.oceanengine.com/official)
     */
    icon?: string;
    color?: string;
    backgroundColor?: string;
    confirmButtonText?: string;
    cancelButtonText?: string;
    cancelBroadcast?: string;
    confirmBroadcast?: string;
    size: NotificationSize;
    url?: string;
    avatar?: string;
    audio?: string;
    lyric?: string;
    createdAt: string;
    constructor(option: NotificationOption);
}
declare class AppReminderNotification extends AppNotification {
    constructor(option: ReminderNotificationOption);
}

/**
 * NotificationApi提供了发送通知的能力
 */
interface INotificationApi {
    /**
     * 发送自定义通知
     * @param notification
     */
    send: (notification: AppNotification) => Promise<void>;
    /**
     * 隐藏通知
     */
    hide: () => Promise<void>;
    /**
     * @param message string
     * @param duration number  持续时间，单位毫秒，默认5000
     */
    success: (message: string, duration?: number) => Promise<void>;
    /**
     * @param message string
     * @param duration number  持续时间，单位毫秒，默认5000
     */
    error: (message: string, duration?: number) => Promise<void>;
    /**
     * @param message string
     * @param duration number  持续时间，单位毫秒，默认5000
     */
    warning: (message: string, duration?: number) => Promise<void>;
    /**
     * @param message string
     * @param duration number  持续时间，单位毫秒，默认5000
     */
    info: (message: string, duration?: number) => Promise<void>;
    reminder: (option: ReminderNotificationOption) => Promise<void>;
}

type NotificationApiMethods = keyof INotificationApi;
declare enum NotificationApiEvent {
    CONFIRM = "event::cn.widgetjs.core.notification.confirm",
    CANCEL = "event::cn.widgetjs.core.notification.cancel",
    HIDE = "event::cn.widgetjs.core.notification.hide"
}
declare class NotificationApiImpl extends BaseApi<NotificationApiMethods> implements INotificationApi {
    /**
     * 来电
     * @param avatar    头像地址
     * @param audio     音频地址
     * @param title     标题文件
     * @param message   初始消息
     * @param lyric     歌词字符串
     */
    call(avatar: string, audio: string, title: string, message: string, lyric: string): Promise<void>;
    send(notification: AppNotification): Promise<any>;
    reminder(option: ReminderNotificationOption): Promise<any>;
    advanceCountdown(message: string, targetTime: string, title?: string): Promise<any>;
    countdown(message: string, targetTime: string): Promise<void>;
    success(message: string, duration?: number): Promise<void>;
    error(message: string, duration?: number): Promise<void>;
    warning(message: string, duration?: number): Promise<void>;
    info(message: string, duration?: number): Promise<void>;
    /**
     * 隐藏通知
     */
    hide(): Promise<void>;
    getChannel(): string;
}
declare const NotificationApi: NotificationApiImpl;

/**
 * @deprecated use DeployedMode instead
 */
declare enum HostedMode {
    NORMAL = 1,
    /**
     * 悬浮窗
     */
    OVERLAP = 16,
    WALLPAPER = 256,
    SCREEN = 4096,
    BACKGROUND = 65536,
    /**
     * 页面
     */
    PAGE = 1048576,
    ALL = 1118481
}
declare enum DeployMode {
    /**
     * 桌面组件，默认
     */
    NORMAL = 1,
    /**
     * 悬浮窗
     */
    OVERLAP = 16,
    /**
     * 后台组件，没有界面，一般在后台执行定时任务
     */
    BACKGROUND = 65536,
    /**
     * 全部支持
     */
    ALL = 1118481
}

declare class WidgetParams {
    static readonly PARAM_PREFIX = "w_";
    static readonly PARAM_ID = "id";
    static readonly PARAM_WIDTH = "width";
    static readonly PARAM_HEIGHT = "height";
    static readonly PARAM_WIDTH_PX = "width_px";
    static readonly PARAM_HEIGHT_PX = "height_px";
    static readonly PARAM_X = "x";
    static readonly PARAM_Y = "y";
    static readonly PARAM_LANG = "lang";
    static readonly PARAM_THEME = "theme";
    static readonly PARAM_MODE = "mode";
    static readonly PARAM_RADIUS = "radius";
    static readonly PARAM_NAME = "name";
    static readonly PARAM_TITLE = "title";
    static readonly PARAM_PREVIEW = "preview";
    static readonly PARAMS: string[];
    id?: string;
    width?: number;
    widthPx?: number;
    heightPx?: number;
    height?: number;
    x?: number;
    y?: number;
    preview?: boolean;
    lang?: string;
    theme?: ThemeMode;
    mode?: DeployMode;
    radius?: number;
    name?: string;
    title?: string;
    /**
     * 将组件参数转为url参数
     * @param object
     * @return URLSearchParams  w_w=2&w_h=2&w_id=21&w_width=156&w_height=156
     */
    toUrlParams(): URLSearchParams;
    getPersistKey(): string;
    /**
     * 从当前地址解析组件参数：
     * http://localhost:8080/#/widget/config/labor_progress?w_w=2&w_h=2&w_width=156&w_height=156
     * =>
     *  {width:2,height:2,id:21,width_px:156,height_px:156}
     */
    static fromCurrentLocation(): WidgetParams;
    static fromLocation(url: string): WidgetParams;
    private static setValue;
    /**
     * 从对象键值对中初始化组件参数
     * {w_width:2,w_height:2,w_id:21,w_width_px:156,w_height_px:156}=>
     *  {width:2,height:2,id:21,width_px:156,height_px:156}
     * @param object
     */
    static fromObject(object: any): WidgetParams;
}
declare enum ThemeMode {
    AUTO = "auto",
    LIGHT = "LIGHT",
    DARK = "DARK"
}

interface IDeployedPage {
    id: string;
    name: string;
    packageName: string;
    x: number;
    y: number;
    height: number;
    width: number;
    proxy?: string;
}
declare class DeployedPage implements IDeployedPage {
    name: string;
    packageName: string;
    x: number;
    y: number;
    height: number;
    width: number;
    proxy?: string;
    id: string;
}

declare class DeployedWidget extends DeployedPage {
    shortcut?: string;
    deployMode: number;
    isOverlap(): boolean;
}

/**
 * DeployedWidgetApi provides methods for managing deployed widgets within the application.
 * It allows for the removal, retrieval, and configuration of deployed widgets,
 * as well as the ability to manipulate their settings and behavior.
 * @remarks
 */
interface IDeployedWidgetApi {
    removeDeployedWidget: (id: string) => Promise<void>;
    removeDeployedWidgetByName: (name: string) => Promise<DeployedWidget[]>;
    getDeployedWidgets: () => Promise<DeployedWidget[]>;
    openDevTools: (id: string) => Promise<void>;
    /**
     * @deprecated 使用WidgetApi.openConfigPage代替
     * @param id
     */
    openConfigPage: (id?: string, params?: WidgetParams) => Promise<void>;
    registerActiveShortcut: (id: string, shortcut: string) => Promise<boolean>;
    setProxy: (id: string, proxy: string) => Promise<boolean>;
    getDeployedWidget: (id: string) => Promise<DeployedWidget>;
    /**
     * Adds a new widget with the specified options.
     * @param options - The options for the widget to be added.
     * @returns A promise that resolves with an array of added widgets.
     */
    addWidget: (options: AddWidgetOption) => Promise<Widget[]>;
    /**
     * Reloads a deployed widget by its ID.
     * @param id - The unique identifier of the widget to be reloaded.
     */
    reload: (id: string) => Promise<void>;
}

interface AddWidgetOption {
    widgetName: string;
    deployMode: DeployMode;
    packageJsonUrl?: string;
}
type DeployedWidgetApiMethods = keyof IDeployedWidgetApi;
declare class DeployedWidgetApiImpl extends BaseApi<DeployedWidgetApiMethods> implements IDeployedWidgetApi {
    getChannel(): string;
    /**
     * 移除组件
     * @param id
     */
    removeDeployedWidget(id: string): Promise<any>;
    addWidget(options: AddWidgetOption): Promise<Widget[]>;
    /**
     * 通过组件名移除已添加的组件
     * @param name  组件名
     */
    removeDeployedWidgetByName(name: string): Promise<DeployedWidget[]>;
    /**
     * 获取已添加的组件
     * @param name  组件名，可以不传
     */
    getDeployedWidgets(name?: string): Promise<DeployedWidget[]>;
    getDeployedWidget(id: string): Promise<DeployedWidget>;
    /**
     * Opens the dev tools for a widget with the specified ID.
     *
     * @param {string} widgetId - The ID of the widget to open the dev tools for.
     * @return {Promise} A Promise that resolves when the dev tools are opened.
     */
    openDevTools(widgetId: string): Promise<any>;
    openConfigPage(widgetId?: string, params?: WidgetParams): Promise<any>;
    /**
     * 注册激活、呼出、置顶组件快捷键
     * @param widgetId  组件id
     * @param shortcut  如果传空或者不传，则会取消快捷键。更多快捷键配置，请查看Accelerator用法
     *                  https://www.electronjs.org/docs/latest/api/accelerator
     */
    registerActiveShortcut(widgetId: string, shortcut?: string): Promise<boolean>;
    setProxy(widgetId: string, proxy: string): Promise<boolean>;
    reload(id: string): Promise<any>;
}
declare const DeployedWidgetApi: DeployedWidgetApiImpl;

interface Size {
    height: number;
    width: number;
}

interface Display {
    /**
     * Can be `available`, `unavailable`, `unknown`.
     */
    accelerometerSupport: ('available' | 'unavailable' | 'unknown');
    /**
     * the bounds of the display in DIP points.
     */
    bounds: Rectangle;
    /**
     * The number of bits per pixel.
     */
    colorDepth: number;
    /**
     *  represent a color space (three-dimensional object which contains all realizable
     * color combinations) for the purpose of color conversions
     */
    colorSpace: string;
    /**
     * The number of bits per color component.
     */
    depthPerComponent: number;
    /**
     * The display refresh rate.
     */
    displayFrequency: number;
    /**
     * Unique identifier associated with the display.
     */
    id: number;
    /**
     * `true` for an internal display and `false` for an external display
     */
    internal: boolean;
    /**
     * User-friendly label, determined by the platform.
     */
    label: string;
    /**
     * Whether or not the display is a monochrome display.
     */
    monochrome: boolean;
    /**
     * Can be 0, 90, 180, 270, represents screen rotation in clock-wise degrees.
     */
    rotation: number;
    /**
     * Output device's pixel scale factor.
     */
    scaleFactor: number;
    size: Size;
    /**
     * Can be `available`, `unavailable`, `unknown`.
     */
    touchSupport: ('available' | 'unavailable' | 'unknown');
    /**
     * the work area of the display in DIP points.
     */
    workArea: Rectangle;
    workAreaSize: Size;
}

interface IDeviceApi {
    getCursorScreenPoint: () => Promise<Point>;
    sendCtrlV: () => Promise<void>;
    isAllKeyReleased: () => Promise<boolean>;
    getDisplayNearestPoint: (point: Point) => Promise<Display>;
    getAllDisplays: () => Promise<Display[]>;
    getPrimaryDisplay: () => Promise<Display>;
}
type DeviceApiMethods = keyof IDeviceApi;
declare const DeviceApi: IDeviceApi;

declare enum Channel {
    NOTIFICATION = "channel::cn.widgetjs.core.notification",
    BROWSER_WINDOW = "channel::cn.widgetjs.core.browser_window",
    BROADCAST = "channel::cn.widgetjs.core.broadcast",
    WIDGET = "channel::cn.widgetjs.core.widget",
    WIDGET_PACKAGE = "channel::cn.widgetjs.core.widget.package",
    DEPLOYED_WIDGET = "channel::cn.widgetjs.core.deployed_widget",
    APP = "channel::cn.widgetjs.core.app",
    SYSTEM = "channel::cn.widgetjs.core.system",
    DIALOG = "channel::cn.widgetjs.core.dialog",
    CLIPBOARD = "channel::cn.widgetjs.core.clipboard",
    FILE = "channel::cn.widgetjs.core.file",
    SCREEN = "channel::cn.widgetjs.core.screen",
    MENU = "channel::cn.widgetjs.core.menu",
    SHORTCUT = "channel::cn.widgetjs.core.shortcut",
    LOG = "channel::cn.widgetjs.core.log",
    DEVICE = "channel::cn.widgetjs.core.device",
    MOUSE = "channel::cn.widgetjs.core.mouse",
    KEYBOARD = "channel::cn.widgetjs.core.keyboard",
    /**
     * @deprecated
     */
    STORE = "channel::cn.widgetjs.core.store",
    STORAGE = "channel::cn.widgetjs.core.storage",
    PROCESS = "channel::cn.widgetjs.core.process"
}

interface IClipboardApi {
    getSelectedText(): Promise<string | undefined>;
    getText(): Promise<string | undefined>;
    writeText(text: string): Promise<void>;
}
type ClipboardApiMethods = keyof IClipboardApi;
declare enum ClipboardApiEvent {
    CHANGED = "clipboard-changed"
}
declare const ClipboardApi: IClipboardApi;

type WidgetPermission = 'keyboard' | 'mouse' | 'clipboard' | 'notification' | 'storage' | 'network' | 'cpu' | 'system-info';

interface MetaInfo {
    [key: string]: string | number | boolean;
}
interface IWindowSize {
    width: number;
    height: number;
    maxWidth?: number;
    maxHeight?: number;
    minWidth?: number;
    minHeight?: number;
}
interface IPageOptions extends IWindowSize {
    name: string;
    /**
     * 当showInSearch为true时,此项必填
     */
    title: LanguageTextMap;
    /**
     * 当showInSearch为true时,此项必填
     */
    description?: LanguageTextMap;
    /**
     * 当showInSearch为true时,此项必填
     */
    keywords?: WidgetKeyword[];
    lang: LanguageCode;
    packageName?: string;
    /**
     * 当showInSearch为true时,此项必填
     */
    previewImage?: string;
    /**
     * 是否在搜索中显示
     */
    showInSearch?: boolean;
    /**
     * 悬浮窗模式 是否可移动
     * @deprecated
     */
    movable?: boolean;
    /**
     * @deprecated
     */
    resizable?: boolean;
    /**
     * @deprecated
     */
    backgroundThrottling?: boolean;
    security?: boolean;
    /**
     * @deprecated
     */
    webviewTag?: boolean;
    path: string;
    /**
     * 是否只能添加一次
     */
    singleton?: boolean;
    permissions?: WidgetPermission[];
    meta?: MetaInfo;
    broadcastChannels?: string[];
}
interface IPage {
    readonly name: string;
    /**
     * 窗口标题，显示在界面上的，
     * https://zh.m.wikipedia.org/zh-hans/ISO_639-1
     */
    readonly title: LanguageTextMap;
    readonly permissions: WidgetPermission[];
    readonly webviewTag: boolean;
    /**
     * 窗口介绍
     */
    readonly description: LanguageTextMap;
    readonly keywords: WidgetKeyword[];
    /**
     * 组件默认语言
     */
    readonly lang: LanguageCode;
    readonly width: number;
    packageName?: string | null;
    readonly height: number;
    readonly maxWidth: number;
    readonly maxHeight: number;
    readonly minWidth: number;
    readonly minHeight: number;
    readonly movable: boolean;
    readonly singleton: boolean;
    readonly resizable: boolean;
    readonly path: string;
    readonly meta: {
        [key: string]: string | number | boolean;
    };
    readonly backgroundThrottling: boolean;
    /**
     * 预览图片，可以是GIF
     */
    readonly previewImage?: string;
}
declare class Page implements IPage {
    /**
     * 页面名称,名称必须以包名开头，如果以.开头，会自动加上包名<br>
     * 假设包名为`example.com`，以下两种写法等价
     * @example example.com.countdown
     * @example .countdown
     */
    name: string;
    /**
     * 窗口标题，显示在界面上的，
     * @see https://zh.m.wikipedia.org/zh-hans/ISO_639-1
     */
    readonly title: LanguageTextMap;
    /**
     * 窗口介绍
     */
    readonly description: LanguageTextMap;
    readonly keywords: WidgetKeyword[];
    readonly security: boolean;
    readonly permissions: WidgetPermission[];
    /**
     * 组件默认语言
     */
    readonly lang: LanguageCode;
    readonly width: number;
    packageName?: string | null;
    readonly height: number;
    readonly maxWidth: number;
    readonly webviewTag: boolean;
    readonly maxHeight: number;
    readonly minWidth: number;
    readonly minHeight: number;
    readonly movable: boolean;
    readonly singleton: boolean;
    readonly resizable: boolean;
    readonly path: string;
    readonly meta: {
        [key: string]: string | number | boolean;
    };
    readonly backgroundThrottling: boolean;
    /**
     * 预览图片，可以是GIF
     */
    readonly previewImage?: string;
    constructor(options: IPageOptions);
    /**
     * 获取组件标题
     * @param lang 语言环境，不传则获取默认语言
     */
    getTitle(lang?: LanguageCode): string | undefined;
    /**
     * 获取组件描述
     * @param lang 语言环境，不传则获取默认标题
     */
    getDescription(lang?: LanguageCode): string | undefined;
    static parseJSON(json: string): Page;
    static parseObject(obj: any): Page;
    isResizable(): boolean;
}

interface LocalPackageUrlInfo {
    /**
     * 入口文件，默认为index.html，也可以是/
     * @example remote package: https://rtugeek.gitee.io/hotspot/index.html
     * @example local package: index.html
     * @deprecated use entryFile instead
     */
    entry?: string;
    /**
     * 需以 / 开头
     * @example /index.html
     */
    entryFile?: string;
    /**
     * 是否使用hash路由
     */
    hash?: boolean;
}
interface RemotePackageUrlInfo extends LocalPackageUrlInfo {
    /**
     * 部署到服务器的base path，只在远程组件包中生效，需以/开始
     * @example /hotspot
     */
    base?: string;
    /**
     * 域名地址，不带协议
     * @example widgetjs.cn
     */
    hostname: string;
}
interface WidgetPackageOptions extends LocalPackageUrlInfo {
    name: string;
    version?: string;
    author: string;
    homepage?: string;
    title: LanguageTextMap;
    permissions?: WidgetPermission[];
    description: LanguageTextMap;
    /**
     * 远程组件包入口文件
     * @deprecated
     */
    remoteEntry?: string;
    /**
     * @deprecated
     */
    remotePackage?: string;
    remote?: RemotePackageUrlInfo;
    icon?: string;
    lang?: LanguageCode;
    widgets?: Widget[];
    /**
     * 是否处于开发模式
     */
    development?: boolean;
    devOptions?: DevOptions;
    requiredAppVersion?: string;
}
declare class WidgetPackage implements Omit<RemotePackageUrlInfo, 'hostname'> {
    /**
     * 组件包名,一般为域名倒写，e.g. com.example
     */
    readonly name: string;
    /**
     * 组件包版本，可以为空，默认采用package.json里的版本
     * e.g. 1.0.2
     */
    version?: string;
    /**
     * 组件包所需的App版本
     */
    requiredAppVersion?: string;
    /**
     * 组件作者署名
     */
    readonly author: string;
    development?: boolean;
    /**
     * 组件首页
     */
    readonly homepage?: string;
    /**
     * 组件描述
     */
    readonly title: {
        [key: LanguageCode | string]: string;
    };
    /**
     * 组件描述
     */
    readonly description: {
        [key: LanguageCode | string]: string;
    };
    /**
     * 本地组件入口文件，通常为 index.html
     */
    entry: string | 'index.html';
    /**
     * 远程组件包入口文件
     * @deprecated
     */
    remoteEntry?: string;
    /**
     * 组件包json文件路径
     * @deprecated
     * @example https://rtugeek.gitee.io/hotspot/widget.json
     */
    readonly remotePackage?: string;
    readonly local?: LocalPackageUrlInfo;
    readonly remote?: RemotePackageUrlInfo;
    /**
     * 组件包图标
     */
    readonly icon?: string;
    /**
     * Hash路由模式，默认为true
     */
    readonly hash: boolean;
    /**
     * 可能是网络地址，或者本地路径（解压后的文件夹路径）,
     * 网络地址：https://www.bilibili.com
     * 本地地址：file:///C:/Users/neo/Desktop
     * 在测试时。地址通常为: http://127.0.0.1:8080
     */
    url: string;
    readonly widgets: Widget[];
    readonly pages: Page[];
    devOptions?: DevOptions;
    constructor(options: WidgetPackageOptions);
    static parseJSON(json: string): WidgetPackage;
    static parseObject(obj: any): WidgetPackage;
    /**
     * 获取组件包标题
     * @param lang 语言环境，不传则获取默认语言
     */
    getTitle(lang?: LanguageCode): string | undefined;
    /**
     * 获取组件包描述
     * @param lang 语言环境，不传则获取默认标题
     */
    getDescription(lang?: LanguageCode): string | undefined;
}
interface DevOptions {
    folder?: string;
    route?: boolean;
    devUrl?: string;
    remoteEntry?: string;
}

/**
 * WidgetApi 接口定义了一系列用于控制组件的方法，这些方法提供了组件的注册、升级、获取、打开设置页面、重新加载等功能
 */
interface IWidgetApi {
    /**
     * 注册组件
     * @param widgets
     */
    registerWidgets: (widgets: Widget[]) => Promise<void>;
    /**
     * @deprecated
     */
    registerWidgetPackage: (widgetPackage: WidgetPackage) => Promise<void>;
    /**
     * 设置组件是否可以左键拖动
     * @param draggable boolean true-启用左键拖动 false-禁用左键拖动
     * @remarks 注意：只对悬浮窗组件(DeployMode.OVERLAP)有效
     */
    setMouseDraggable: (draggable: boolean) => Promise<void>;
    /**
     * 升级组件包
     * @param packageName 组件包名
     */
    upgradePackage: (packageName: string) => Promise<void>;
    /**
     * 获取所有组件
     * @return Promise<Widget[]>
     */
    getWidgets: () => Promise<Widget[]>;
    /**
     * 通过组件名称获取组件
     * @param name string 组件名
     * @return Promise<Widget>
     */
    getWidget: (name: string) => Promise<Widget>;
    /**
     * @param name
     * @deprecated
     */
    getWidgetPackage: (name: string) => Promise<WidgetPackage | undefined>;
    /**
     * @deprecated
     */
    getWidgetPackages: () => Promise<WidgetPackage[]>;
    /**
     * 打开组件设置页面
     * @param id string 组件id
     */
    openConfigPage: (id?: string) => Promise<void>;
    /**
     * @param name
     */
    openConfigPageByName: (name: string) => Promise<void>;
    /**
     * 重新加载组件
     */
    reload: () => Promise<void>;
    /**
     *
     * @param packageName
     * @deprecated
     */
    getWidgetPackageUrl: (packageName: string) => Promise<string | null>;
}

type WidgetApiMethods = keyof IWidgetApi;
declare enum WidgetApiEvent {
    DATA_CHANGED = "event::cn.widgetjs.core.widget.data-changed",
    EDIT_DESKTOP_WIDGETS = "event::cn.widgetjs.core.widget.desktop.edit",
    PACKAGE_UPGRADE = "event::cn.widgetjs.core.widget.package.upgraded",
    PACKAGE_INSTALLED = "event::cn.widgetjs.core.widget.package.installed"
}
declare class WidgetApiImpl extends BaseApi<WidgetApiMethods> implements IWidgetApi {
    reload(): Promise<void>;
    getChannel(): string;
    registerWidgets(widgets: Widget[]): Promise<any>;
    registerWidgetPackage(widgetPackage: WidgetPackage): Promise<any>;
    getWidgets(): Promise<Widget[]>;
    openConfigPage(widgetId?: string): Promise<any>;
    openConfigPageByName(widgetName: string): Promise<any>;
    /**
     * @deprecated
     */
    getWidgetPackages(): Promise<WidgetPackage[]>;
    /**
     *
     * @param name package name
     */
    getWidget(name: string): Promise<Widget>;
    /**
     * @param name package name
     * @deprecated
     */
    getWidgetPackage(name: string): Promise<WidgetPackage | undefined>;
    getWidgetPackageUrl(packageName: string): Promise<string | null>;
    upgradePackage(packageName: string): Promise<void>;
    setMouseDraggable(draggable: boolean): Promise<void>;
}
declare const WidgetApi: WidgetApiImpl;

declare class ApiConstants {
    static readonly CONFIG_LAUNCH_AT_STARTUP = "CONFIG_LAUNCH_AT_STARTUP";
    static readonly CONFIG_WIDGET_TITLE_COLOR = "CONFIG_WIDGET_TITLE_COLOR";
    static readonly CONFIG_DEBUG_MODE = "cn.widgetjs.config.debug";
    static readonly CONFIG_GRID_CELL_SIZE = "cn.widgetjs.config.grid.size";
    static readonly SHORTCUT_PIN_DESKTOP_WIDGETS = "cn.widgetjs.config.shortcut.pin_desktop_widgets";
}

/**
 * ShortcutApi 提供了注册快捷键的能力，当快捷键被触发时，会发送广播事件 {@link BroadcastEvent}
 */
interface IShortcutApi {
    /**
     * 注册快捷键, 如果注册成功, 触发快捷键时，会发送广播事件 {@link BroadcastEvent}
     * @see [Electron Accelerator](https://www.electronjs.org/docs/latest/api/accelerator)
     * @param shortcut string
     * @return Promise<boolean> true 注册成功，false 注册失败
     * @example
     * ```typescript
     * //Meta 通常为windows键
     * ShortcutApi.register('Ctrl+Meta+Y')
     * ```
     */
    register: (shortcut: string) => Promise<boolean>;
    /**
     * 注销快捷键
     * @param shortcut string
     * @example
     * ```typescript
     * //Meta 通常为windows键
     * ShortcutApi.unregister('Ctrl+Meta+Y')
     * ```
     */
    unregister: (shortcut: string) => void;
}
/**
 * ShortcutApiEvent
 */
declare enum ShortcutApiEvent {
    /**
     * 快捷键触发事件
     */
    TRIGGERED = "channel::cn.widgetjs.core.shortcut.triggered"
}

type ShortcutApiMethods = keyof IShortcutApi;
declare const ShortcutApi: IShortcutApi;

interface BroadcastEventOptions {
    event: WidgetApiEvent | AppApiEvent | string;
    /**
     * 发送人，用于标记发送源，一般为组件名，如：com.example.widgets.countdown
     */
    sender?: string;
    /**
     * 广播事件携带的数据，只支持部分数据类型。
     * @see https://developer.mozilla.org/en-US/docs/Web/API/Web_Workers_API/Structured_clone_algorithm
     */
    payload?: any;
}
declare class BroadcastEvent {
    readonly event: string;
    readonly sender?: string;
    payload?: any;
    constructor(options: BroadcastEventOptions);
}

/**
 * BroadcastApi provides the ability to send and listen to broadcast events,
 * typically used for component packages to listen for system or application events,
 * or for communication and data transfer between component packages.
 */
interface IBroadcastApi {
    /**
     * send broadcast event
     * @param event
     */
    send: (event: BroadcastEvent) => Promise<void>;
    /**
     * register listener for broadcast event
     * @param event
     */
    register: (...event: BroadcastEventType[]) => Promise<void>;
    /**
     * Unregister broadcast event
     * @param event
     */
    unregister: (...event: BroadcastEventType[]) => Promise<void>;
}

type BroadcastEventType = WidgetApiEvent | BrowserWindowApiEvent | ShortcutApiEvent | ClipboardApiEvent | string;
type BroadcastApiMethods = keyof IBroadcastApi;
declare const BroadcastApi: IBroadcastApi;

/**
 * ProcessApi 提供进程信息获取功能
 */
interface IProcessApi {
    getBlinkMemoryInfo: () => Promise<Electron.BlinkMemoryInfo>;
    getHeapStatistics: () => Promise<Electron.HeapStatistics>;
    /**
     * 获取系统版本信息
     * @example '10.0.17763'
     */
    getSystemVersion: () => Promise<string>;
    /**
     * 获取当前应用内存信息
     */
    getProcessMemoryInfo: () => Promise<Electron.ProcessMemoryInfo>;
}
type ProcessApiMethods = keyof IProcessApi;

declare const ProcessApi: IProcessApi;

/**
 * AppApi 接口定义了与应用程序相关的一系列方法。这些方法提供了应用程序配置管理、版本信息获取、路径获取以及应用内置窗口操作等功能。
 * @see [Electron API App](https://www.electronjs.org/docs/latest/api/app)
 */
interface IAppApi {
    /**
     * 设置配置
     * @param key string
     * @param value string | number | boolean
     */
    setConfig: (key: string | AppApiConstants, value: string | number | boolean) => Promise<any>;
    /**
     * 获取配置
     * @param key
     * @param defaultValue
     * @return Promise<string | number | boolean>
     */
    getConfig: <T extends string | number | boolean>(key: string | AppApiConstants, defaultValue: T) => Promise<T>;
    /**
     * 获取版本信息
     * @param type string - 可选。指定要获取的版本类型。
     *      <ol>
     *        <li>`app`: Get app's version with Semantic Versioning format.
     *        The version is different from Microsoft store's version.
     *        For example, if the app's version is `24.1.1`, Microsoft store's version will be `24.1.1.0`</li>
     *        <li>`electron`: 获取 Electron 框架的版本。</li>
     *        <li>`chrome`: 获取 Electron 使用的 Chromium 版本。</li>
     *        <li>`node`: 获取 Node.js 的版本。</li>
     *        <li>`v8`: 获取 V8 引擎的版本。</li>
     *      </ol>
     * @return Promise<string>
     */
    getVersion: (type?: 'app' | 'electron' | 'chrome' | 'node' | 'v8') => Promise<string>;
    /**
     * Get App's runtime info (e.g. app name, os/electron/node version, etc.)
     */
    getRuntimeInfo: () => Promise<AppRuntimeInfo>;
    /**
     * 获取Preload JS路径
     * @see [Using Preload Scripts](https://www.electronjs.org/docs/latest/tutorial/tutorial-preload)
     * @return Promise<string>
     */
    getPreloadPath: () => Promise<string>;
    /**
     * 获取应用安装路径
     * @return Promise<string>
     */
    getAppPath: () => Promise<string>;
    /**
     * Open the app's add/search widget window
     */
    openAddWidgetWindow: () => Promise<void>;
    /**
     * Open the app's setting window
     */
    openSettingWindow: () => Promise<void>;
    /**
     * Get the app's icon file path
     * @return Promise<string>
     */
    getIconFile: () => Promise<string>;
    /**
     * Check if the app is running as Windows Store app (appx)
     * @return Promise<boolean>
     */
    isWindowsStore: () => Promise<boolean>;
    /**
     * Get app's language, if user has not set, return `navigator.language`
     */
    getLanguageCode: () => Promise<string>;
    /**
     * Set app's language
     * @param code
     */
    setLanguageCode: (code: LanguageCode) => Promise<void>;
    /**
     * Set app's global proxy settings, set empty string to disable proxy
     * @param config
     * @example
     * ```typescript
     * AppApi.setProxy({
     *     proxyRules:'socks5://127.0.0.1:7890'
     * })
     * ```
     */
    setProxy: (config: ProxyConfig) => Promise<void>;
    getProxy: () => Promise<ProxyConfig>;
    /**
     * Set app's global theme CSS
     * @param css
     */
    setThemeCSS: (css: string) => Promise<void>;
    /**
     * Get the app's global theme CSS
     * @return Promise<string> If the theme CSS is not set, return empty string
     */
    getThemeCSS: () => Promise<string>;
    /**
     * enable/disable developer mode
     */
    setDevMode: (enable: boolean) => Promise<void>;
    /**
     * get developer mode is enabled
     */
    getDevMode: () => Promise<boolean>;
    /**
     * Get the app's desktop grid system cell size
     */
    getGridCellSize: () => Promise<number>;
    /**
     * Set the app's desktop grid system cell size
     * @param size
     */
    setGridCellSize: (size: number) => Promise<void>;
}
type AppApiMethods = keyof IAppApi;
/**
 * AppApiEvent
 */
declare enum AppApiEvent {
    /**
     * 应用设置变更时触发
     */
    CONFIG_CHANGED = "event::cn.widgetjs.core.app.config.changed",
    /**
     * 桌面组件网格窗口移动时触发
     */
    MOVING_GRID_WINDOW = "event::cn.widgetjs.core.app.moving.grid.window",
    /**
     * 桌面组件网格窗口停止移动时触发
     */
    STOP_MOVING_GRID_WINDOW = "event::cn.widgetjs.core.app.moving.grid.window.stop",
    /**
     * 应用代理发生变化
     */
    PROXY_CHANGED = "event::cn.widgetjs.core.app.proxy.changed",
    /**
     * 应用语言发生变化
     */
    LANGUAGE_CHANGED = "event::cn.widgetjs.core.app.language.changed"
}
/**
 * AppApiConstants
 */
declare enum AppApiConstants {
    /**
     * 桌面组件网格大小
     */
    CONFIG_GRID_CELL_SIZE = "cn.widgetjs.config.grid.size",
    /**
     * 应用主题CSS设置
     */
    CONFIG_WIDGET_THEME_CSS = "cn.widgetjs.config.widget.theme.css",
    /**
     * 应用全局代理设置
     */
    CONFIG_PROXY = "cn.widgetjs.config.app.proxy",
    CONFIG_DEV_MODE = "cn.widgetjs.config.app.dev.mode",
    /**
     * 应用语言设置
     */
    CONFIG_LANGUAGE = "cn.widgetjs.config.app.language"
}

/**
 * DialogApi 提供文件、文件夹选择功能
 */
interface IDialogApi {
    /**
     * 选取单个文件
     * @param extensions 允许的文件后缀格式，如：["txt","docx","gif"]
     */
    pickFile: (extensions?: string[]) => Promise<string | undefined>;
    /**
     * 选取文件夹
     */
    pickFolder: () => Promise<string | undefined>;
}
type DialogApiMethods = keyof IDialogApi;

/**
 * WidgetPackageApi 提供了组件包的升级、获取、安装等功能
 */
interface IWidgetPackageApi {
    /**
     * 升级组件包
     * @param packageName   组件包名称
     * @param remoteUrlInfo
     */
    upgrade: (packageName: string, remoteUrlInfo: RemotePackageUrlInfo) => Promise<void>;
    /**
     * 获取组件包的首页url信息
     * @param packageName
     */
    getIndexUrl: (packageName: string) => Promise<string | null>;
    /**
     * 获取组件包入口url信息
     * @param packageName
     */
    getEntryUrl: (packageName: string) => Promise<string | null>;
    /**
     * 通过包名获取组件包信息
     * @param name
     */
    getPackage: (name: string) => Promise<WidgetPackage | undefined>;
    /**
     * 获取已经安装的组件包
     */
    getPackages: () => Promise<WidgetPackage[]>;
    /**
     * 安装组件包
     * @param widgetPackage
     */
    install: (widgetPackage: WidgetPackage) => Promise<void>;
}
type WidgetPackageApiMethods = keyof IWidgetPackageApi;
/**
 * WidgetPackageApiEvent
 */
declare enum WidgetPackageApiEvent {
    /**
     * 组件包升级事件
     */
    PACKAGE_UPGRADE = "event::cn.widgetjs.core.widget.package.upgraded",
    /**
     * 组件包安装事件
     */
    PACKAGE_INSTALLED = "event::cn.widgetjs.core.widget.package.installed"
}

/**
 * LogApi提供了日志输出的方法，日志会保存在用户的`当前用户名/文档/桌面组件/logs/日期/组件包名.log`文件中
 */
interface ILogApi {
    info: (...data: any[]) => void;
    error: (...data: any[]) => void;
    warn: (...data: any[]) => void;
    log: (...data: any[]) => void;
    json: (data: any) => void;
}
type LogApiMethods = keyof ILogApi;

/**
 * MouseApi
 */
interface IMouseApi {
    /**
     * 创建鼠标屏幕边缘热点，通常用于贴边窗口隐藏
     * @param rect
     */
    createMouseHotspot: (rect: Rectangle) => Promise<void>;
    /**
     * 移除鼠标屏幕边缘热点
     */
    clearMouseHotspot: () => Promise<void>;
}
/**
 * SystemApiEvent
 */
declare enum MouseApiEvent {
    /**
     * 系统日期变更事件
     */
    HOTSPOT_ACTIVE = "event::cn.widgetjs.core.mouse.hotspot.active"
}
type MouseApiMethods = keyof IMouseApi;

declare const AppApi: IAppApi;

declare const DialogApi: IDialogApi;

type BaseType = string | number | boolean;
/**
 * StorageApi 接口定义了用于存储和检索数据的方法，包括加密和解密功能。
 */
interface IStorageApi {
    /**
     * 获取存储中的值。
     * @param key 键名
     * @param defaultValue 可选，默认值
     */
    get: <T extends BaseType>(key: string, defaultValue?: T) => Promise<T | null>;
    /**
     * 设置存储中的值。
     * @param key 键名
     * @param value 要存储的值，可以是 BaseType 或对象
     */
    set: (key: string, value: BaseType | object) => Promise<string>;
    /**
     * 获取存储中的对象值。
     * @param key 键名
     * @param defaultValue 可选，默认值
     */
    getObject: <T>(key: string, defaultValue?: T) => Promise<T | undefined>;
    /**
     * 删除存储中的值。
     * @param key 键名
     */
    delete: (key: string) => Promise<void>;
    /**
     * 使用 [DPAPI](https://learn.microsoft.com/en-us/windows/win32/api/dpapi/nf-dpapi-cryptprotectdata) 生成的加密密钥对字符串进行加密。根据 Windows 文档：“通常，只有与加密数据的用户具有相同登录凭据的用户才可以解密数据”。因此，内容受到同一计算机上其他用户的保护，但不受同一用户空间中运行的其他应用程序的保护。
     * @param value 要加密的字符串
     * @see [Safe Storage](https://www.electronjs.org/docs/latest/api/safe-storage)
     */
    encryptString: (value: string) => Promise<string>;
    /**
     * 对加密的字符串进行解密。
     * @param value 要解密的字符串
     */
    decryptString: (value: string) => Promise<string>;
    /**
     * 对字符串进行加密并存储。
     * @param key 键名
     * @param value 要加密并存储的字符串
     */
    encryptSet: (key: string, value: string) => Promise<string>;
    /**
     * 获取加密存储中的字符串值。
     * @param key 键名
     * @param defaultValue 可选，默认值
     */
    decryptGet: (key: string, defaultValue?: string) => Promise<string | undefined>;
}

/**
 * @deprecated
 */
interface IStoreApi extends IStorageApi {
}
type StoreApiMethods = keyof IStorageApi;
type StorageApiMethods = keyof IStorageApi;
declare const StorageApi: IStorageApi;
/**
 * @deprecated
 */
declare const StoreApi: IStoreApi;

declare const LogApi: ILogApi;

interface Metadata {
    /** Number value of the EXIF Orientation header, if present */
    orientation?: number | undefined;
    /** Name of decoder used to decompress image data e.g. jpeg, png, webp, gif, svg */
    format?: keyof FormatEnum | undefined;
    /** Total size of image in bytes, for Stream and Buffer input only */
    size?: number | undefined;
    /** Number of pixels wide (EXIF orientation is not taken into consideration) */
    width?: number | undefined;
    /** Number of pixels high (EXIF orientation is not taken into consideration) */
    height?: number | undefined;
    /** Name of colour space interpretation */
    space?: keyof ColourspaceEnum | undefined;
    /** Number of bands e.g. 3 for sRGB, 4 for CMYK */
    channels?: Channels | undefined;
    /** Name of pixel depth format e.g. uchar, char, ushort, float ... */
    depth?: string | undefined;
    /** Number of pixels per inch (DPI), if present */
    density?: number | undefined;
    /** String containing JPEG chroma subsampling, 4:2:0 or 4:4:4 for RGB, 4:2:0:4 or 4:4:4:4 for CMYK */
    chromaSubsampling: string;
    /** Boolean indicating whether the image is interlaced using a progressive scan */
    isProgressive?: boolean | undefined;
    /** Number of pages/frames contained within the image, with support for TIFF, HEIF, PDF, animated GIF and animated WebP */
    pages?: number | undefined;
    /** Number of pixels high each page in a multi-page image will be. */
    pageHeight?: number | undefined;
    /** Number of times to loop an animated image, zero refers to a continuous loop. */
    loop?: number | undefined;
    /** Delay in ms between each page in an animated image, provided as an array of integers. */
    delay?: number[] | undefined;
    /**  Number of the primary page in a HEIF image */
    pagePrimary?: number | undefined;
    /** Boolean indicating the presence of an embedded ICC profile */
    hasProfile?: boolean | undefined;
    /** Boolean indicating the presence of an alpha transparency channel */
    hasAlpha?: boolean | undefined;
    /** The encoder used to compress an HEIF file, `av1` (AVIF) or `hevc` (HEIC) */
    compression?: 'av1' | 'hevc';
    /** Default background colour, if present, for PNG (bKGD) and GIF images, either an RGB Object or a single greyscale value */
    background?: {
        r: number;
        g: number;
        b: number;
    } | number;
    /** Details of each level in a multi-level image provided as an array of objects, requires libvips compiled with support for OpenSlide */
    levels?: LevelMetadata[] | undefined;
    /** Number of Sub Image File Directories in an OME-TIFF image */
    subifds?: number | undefined;
    /** The unit of resolution (density) */
    resolutionUnit?: 'inch' | 'cm' | undefined;
    /** String containing format for images loaded via *magick */
    formatMagick?: string | undefined;
}

interface CpuCurrentSpeedData {
    min: number;
    max: number;
    avg: number;
    cores: number[];
}
interface MemData {
    total: number;
    free: number;
    used: number;
    active: number;
    available: number;
    buffcache: number;
    buffers: number;
    cached: number;
    slab: number;
    swaptotal: number;
    swapused: number;
    swapfree: number;
    writeback: number | null;
    dirty: number | null;
}
interface CpuCacheData {
    l1d: number;
    l1i: number;
    l2: number;
    l3: number;
}
interface CpuData {
    manufacturer: string;
    brand: string;
    vendor: string;
    family: string;
    model: string;
    stepping: string;
    revision: string;
    voltage: string;
    speed: number;
    speedMin: number;
    speedMax: number;
    governor: string;
    cores: number;
    physicalCores: number;
    efficiencyCores?: number;
    performanceCores?: number;
    processors: number;
    socket: string;
    flags: string;
    virtualization: boolean;
    cache: CpuCacheData;
}
interface MemLayoutData {
    size: number;
    bank: string;
    type: string;
    ecc?: boolean | null;
    clockSpeed: number | null;
    formFactor: string;
    manufacturer?: string;
    partNum: string;
    serialNum: string;
    voltageConfigured: number | null;
    voltageMin: number | null;
    voltageMax: number | null;
}
interface DiskLayoutData {
    device: string;
    type: string;
    name: string;
    vendor: string;
    size: number;
    bytesPerSector: number;
    totalCylinders: number;
    totalHeads: number;
    totalSectors: number;
    totalTracks: number;
    tracksPerCylinder: number;
    sectorsPerTrack: number;
    firmwareRevision: string;
    serialNum: string;
    interfaceType: string;
    smartStatus: string;
    temperature: null | number;
    smartData?: SmartData;
}
interface SmartData {
    json_format_version: number[];
    smartctl: {
        version: number[];
        platform_info: string;
        build_info: string;
        argv: string[];
        exit_status: number;
    };
    device: {
        name: string;
        info_name: string;
        type: string;
        protocol: string;
    };
    model_family?: string;
    model_name?: string;
    serial_number?: string;
    firmware_version?: string;
    smart_status: {
        passed: boolean;
    };
    trim?: {
        supported: boolean;
    };
    ata_smart_attributes?: {
        revision: number;
        table: {
            id: number;
            name: string;
            value: number;
            worst: number;
            thresh: number;
            when_failed: string;
            flags: {
                value: number;
                string: string;
                prefailure: boolean;
                updated_online: boolean;
                performance: boolean;
                error_rate: boolean;
                event_count: boolean;
                auto_keep: boolean;
            };
            raw: {
                value: number;
                string: string;
            };
        }[];
    };
    ata_smart_error_log?: {
        summary: {
            revision: number;
            count: number;
        };
    };
    ata_smart_self_test_log?: {
        standard: {
            revision: number;
            table: {
                type: {
                    value: number;
                    string: string;
                };
                status: {
                    value: number;
                    string: string;
                    passed: boolean;
                };
                lifetime_hours: number;
            }[];
            count: number;
            error_count_total: number;
            error_count_outdated: number;
        };
    };
    nvme_pci_vendor?: {
        id: number;
        subsystem_id: number;
    };
    nvme_smart_health_information_log?: {
        critical_warning?: number;
        temperature?: number;
        available_spare?: number;
        available_spare_threshold?: number;
        percentage_used?: number;
        data_units_read?: number;
        data_units_written?: number;
        host_reads?: number;
        host_writes?: number;
        controller_busy_time?: number;
        power_cycles?: number;
        power_on_hours?: number;
        unsafe_shutdowns?: number;
        media_errors?: number;
        num_err_log_entries?: number;
        warning_temp_time?: number;
        critical_comp_time?: number;
        temperature_sensors?: number[];
    };
    user_capacity?: {
        blocks: number;
        bytes: number;
    };
    logical_block_size?: number;
    temperature: {
        current: number;
    };
    power_cycle_count: number;
    power_on_time: {
        hours: number;
    };
}
interface BatteryData {
    hasBattery: boolean;
    cycleCount: number;
    isCharging: boolean;
    voltage: number;
    designedCapacity: number;
    maxCapacity: number;
    currentCapacity: number;
    capacityUnit: string;
    percent: number;
    timeRemaining: number;
    acConnected: boolean;
    type: string;
    model: string;
    manufacturer: string;
    serial: string;
    additionalBatteries?: BatteryData[];
}
interface GraphicsData {
    controllers: GraphicsControllerData[];
    displays: GraphicsDisplayData[];
}
interface GraphicsControllerData {
    vendor: string;
    subVendor?: string;
    vendorId?: string;
    model: string;
    deviceId?: string;
    bus: string;
    busAddress?: string;
    vram: number | null;
    vramDynamic: boolean;
    external?: boolean;
    cores?: number;
    metalVersion?: string;
    subDeviceId?: string;
    driverVersion?: string;
    name?: string;
    pciBus?: string;
    pciID?: string;
    fanSpeed?: number;
    memoryTotal?: number;
    memoryUsed?: number;
    memoryFree?: number;
    utilizationGpu?: number;
    utilizationMemory?: number;
    temperatureGpu?: number;
    temperatureMemory?: number;
    powerDraw?: number;
    powerLimit?: number;
    clockCore?: number;
    clockMemory?: number;
}
interface GraphicsDisplayData {
    vendor: string;
    vendorId: string | null;
    model: string;
    productionYear: number | null;
    serial: string | null;
    deviceName: string | null;
    displayId: string | null;
    main: boolean;
    builtin: boolean;
    connection: string | null;
    sizeX: number | null;
    sizeY: number | null;
    pixelDepth: number | null;
    resolutionX: number | null;
    resolutionY: number | null;
    currentResX: number | null;
    currentResY: number | null;
    positionX: number;
    positionY: number;
    currentRefreshRate: number | null;
}
interface OsData {
    platform: string;
    distro: string;
    release: string;
    codename: string;
    kernel: string;
    arch: string;
    hostname: string;
    fqdn: string;
    codepage: string;
    logofile: string;
    serial: string;
    build: string;
    servicepack: string;
    uefi: boolean | null;
    hypervizor?: boolean;
    remoteSession?: boolean;
}
interface VersionData {
    kernel?: string;
    openssl?: string;
    systemOpenssl?: string;
    systemOpensslLib?: string;
    node?: string;
    v8?: string;
    npm?: string;
    yarn?: string;
    pm2?: string;
    gulp?: string;
    grunt?: string;
    git?: string;
    tsc?: string;
    mysql?: string;
    redis?: string;
    mongodb?: string;
    nginx?: string;
    php?: string;
    docker?: string;
    postfix?: string;
    postgresql?: string;
    perl?: string;
    python?: string;
    python3?: string;
    pip?: string;
    pip3?: string;
    java?: string;
    gcc?: string;
    virtualbox?: string;
    dotnet?: string;
}
interface UserData {
    user: string;
    tty: string;
    date: string;
    time: string;
    ip: string;
    command: string;
}
interface CurrentLoadCpuData {
    load: number;
    loadUser: number;
    loadSystem: number;
    loadNice: number;
    loadIdle: number;
    loadIrq: number;
    loadSteal: number;
    loadGuest: number;
    rawLoad: number;
    rawLoadUser: number;
    rawLoadSystem: number;
    rawLoadNice: number;
    rawLoadIdle: number;
    rawLoadIrq: number;
    rawLoadSteal: number;
    rawLoadGuest: number;
}
interface CurrentLoadData {
    avgLoad: number;
    currentLoad: number;
    currentLoadUser: number;
    currentLoadSystem: number;
    currentLoadNice: number;
    currentLoadIdle: number;
    currentLoadIrq: number;
    currentLoadSteal: number;
    currentLoadGuest: number;
    rawCurrentLoad: number;
    rawCurrentLoadUser: number;
    rawCurrentLoadSystem: number;
    rawCurrentLoadNice: number;
    rawCurrentLoadIdle: number;
    rawCurrentLoadIrq: number;
    rawCurrentLoadSteal: number;
    rawCurrentLoadGuest: number;
    cpus: CurrentLoadCpuData[];
}

type HardwareType = 'Cpu' | 'Gpu' | 'Storage' | 'GpuAmd' | 'GpuNvidia' | 'Memory' | 'GpuIntel' | 'Motherboard' | 'SuperIO' | 'Cooler' | 'Battery' | 'Psu' | 'EmbeddedController' | 'Network';
type SensorType = 'Voltage' | 'Current' | 'Power' | 'Clock' | 'Temperature' | 'Load' | 'Frequency' | 'Fan' | 'Flow' | 'Control' | 'Level' | 'Factor' | 'Data' | 'SmallData' | 'Throughput' | 'TimeSpan' | 'Energy' | 'Noise';
interface Hardware {
    id?: number;
    hardwareType: HardwareType;
    hardwareName: string;
    children: HardwareSensor[];
}
interface Node {
    id?: number;
    text?: string;
    min?: number;
    max?: number;
    value?: number;
    unit?: string;
    children?: any[];
}
interface HardwareSensor extends Node {
    sensorId?: string;
    sensorType: SensorType;
    hardwareType?: HardwareType;
    hardwareName?: string;
}

interface SystemFile {
    isDir: boolean;
    name: string;
    absolutePath: string;
    /**
     * mine type
     */
    type: string;
    children?: SystemFile[];
}
interface FileInfo {
    isDir: boolean;
    name: string;
    absolutePath: string;
    /**
     * mine类型
     */
    type?: string;
    /**
     * 格式
     */
    extension?: string;
}
interface ReadDirOptions {
    ignoreDir?: boolean;
    /**
     * @deprecated
     */
    traverseDir?: boolean;
    /**
     * Specifies the maximum depth of a read directory relative to the start directory.
     * A higher value may lead to performance issues, especially for large or deeply nested directories (like node_modules ^_^)
     * default is 1, max is 3
     */
    deep?: number;
    /**
     * glob patterns to filter files
     * @see https://www.npmjs.com/package/fast-glob#pattern-syntax
     */
    pattern?: string | string[];
    /**
     * An array of glob patterns to exclude matches. This is an alternative way to use negative patterns.
     */
    ignore?: string[];
    /**
     * default is false
     */
    onlyDirectories?: boolean;
    /**
     * default is false
     */
    onlyFiles?: boolean;
    /**
     * Allow patterns to match entries that begin with a period (.)
     * @default false
     */
    dot?: boolean;
}
interface DownloadUrlOptions {
    url: string;
    savePath: string;
    fileName: string;
    /**
     * true - overwrite existing
     * false - ignore
     */
    overwrite?: boolean;
}
interface IFileApi {
    readDirectory: (path: string, options?: ReadDirOptions) => Promise<SystemFile>;
    isDirectory: (filePath: string) => Promise<boolean>;
    getMimeType: (absoluteFilePath: string) => Promise<FileTypeResult>;
    downloadUrl: (option: DownloadUrlOptions) => Promise<string>;
    exists: (filePath: string) => Promise<boolean>;
    delete: (filePath: string) => Promise<boolean>;
    getInfo: (absoluteFilePath: string) => Promise<FileInfo>;
    /**
     * 显示系统文件夹
     * @param absoluteFolderPath
     */
    showSystemFolder: (absoluteFolderPath: string) => void;
    /**
     * @param childPath
     * @example childPath = "/images/" will return "C:/Users/username/Documents/widgets/com/exmaple/widget/images"
     * @see     https://sharp.pixelplumbing.com/api-input
     * @return  folder relative to system user's documents folder
     */
    getDocumentFolder: (childPath?: string) => Promise<string>;
    /**
     *
     * @param filePath absolute path
     */
    getPictureMetadata: (filePath: string) => Promise<Metadata>;
    /**
     * 移动文件
     * @param form
     * @param to
     */
    move: (form: string, to: string) => Promise<string>;
    /**
     * read file contents
     * @param filePath
     * @return base64 encoded string
     */
    readFile: (filePath: string) => Promise<string>;
}
type FileApiMethods = keyof IFileApi;
declare const FileApi: IFileApi;

/**
 *
 * SystemApi provides functionality for retrieving system information or interacting with the system.
 */
interface ISystemApi {
    /**
     * Get system wallpaper absolute path
     */
    getWallpaper: () => Promise<string>;
    /**
     * Get hardware information, such as CPU, GPU, Memory, etc.
     * @param hardwareType
     * @return Hardware[]
     */
    getHardware: (hardwareType: HardwareType | HardwareType[]) => Promise<Hardware[]>;
    /**
     * Get hardware sensor information, such as temperature, voltage, fan speed, etc.
     * @param hardwareType
     * @param sensorType
     * @return HardwareSensor[]
     */
    getHardwareSensor: (hardwareType: HardwareType | HardwareType[], sensorType: SensorType | SensorType[]) => Promise<HardwareSensor[]>;
    /**
     * Check if the monitor process is started
     */
    isMonitorStarted: () => Promise<boolean>;
}
/**
 * SystemApiEvent
 */
declare enum SystemApiEvent {
    /**
     * Date changed event
     */
    DATE_CHANGED = "event::cn.widgetjs.core.sys.date.changed"
}

type SystemApiMethods = keyof ISystemApi;
declare const SystemApi: ISystemApi;

declare class WidgetPackageApiImpl extends BaseApi<WidgetPackageApiMethods> implements IWidgetPackageApi {
    getChannel(): string;
    install(widgetPackage: WidgetPackage): Promise<any>;
    upgrade(packageName: string, remoteUrlInfo: RemotePackageUrlInfo): Promise<void>;
    /**
     *
     * @param name package name
     */
    getPackage(name: string): Promise<WidgetPackage | undefined>;
    getIndexUrl(packageName: string): Promise<string | null>;
    getEntryUrl(packageName: string): Promise<string | null>;
    getPackages(): Promise<WidgetPackage[]>;
}
declare const WidgetPackageApi: WidgetPackageApiImpl;

/**
 * MenuApi 接口定义了一系列用于控制窗口的方法，这些方法提供了窗口的显示、隐藏、移动、调整大小等功能
 * @remarks 注意：桌面类型组件不支持窗口移动、调整大小、最大化、最小化等操作
 */
interface IMenuApi {
    /**
     * @deprecated
     */
    addMenuItem: (menuItems: WidgetMenuItem[]) => Promise<void>;
    /**
     * 添加上下文菜单项，最多支持二级菜单
     * @param menuItems
     */
    addContextMenuItem: (menuItems: WidgetMenuItem[]) => Promise<void>;
    /**
     * 移除上下文菜单项
     * @param menuItemIds
     */
    removeContextMenuItem: (menuItemIds: string[]) => Promise<void>;
    /**
     * @deprecated
     */
    removeMenuItem: (menuItemIds: string[]) => Promise<void>;
    /**
     * 显示自定义菜单
     * @param options ShowMenuOption
     */
    showMenu: (options: ShowMenuOption) => Promise<void>;
}
interface ShowMenuOption {
    menuItems: WidgetMenuItem[];
    x?: number;
    y?: number;
}

/**
 * @see [MenuItem](https://www.electronjs.org/docs/api/menu-item)
 */
interface WidgetMenuItem {
    /**
     * 菜单ID
     */
    id: string;
    /**
     * 菜单类型
     */
    type?: 'normal' | 'separator' | 'submenu' | 'checkbox' | 'radio';
    /**
     * 标签
     */
    label: string;
    /**
     * 子标签
     */
    sublabel?: string;
    /**
     * 是否可用
     */
    enabled?: boolean;
    /**
     * 是否显示
     */
    visible?: boolean;
    /**
     * 是否勾选
     */
    checked?: boolean;
    /**
     * 子菜单
     */
    submenu?: Omit<WidgetMenuItem, 'submenu'>[];
    /**
     * 显示在哪个菜单前
     */
    before?: string[];
    /**
     * 显示在哪个菜单后
     */
    after?: string[];
}
declare enum MenuApiEvent {
    ITEM_CLICK = "event::cn.widgetjs.core.menu.item.click"
}
type MenuApiMethods = keyof IMenuApi;
declare const MenuApi: IMenuApi;

declare const MouseApi: IMouseApi;

type SocialType = 'qq' | 'wechat' | 'qq-group' | 'discord' | 'telegram' | 'tiktok' | 'douyin' | 'youtube' | 'instagram' | 'twitter' | 'facebook' | 'kuaishou' | 'bilibili' | 'github' | 'email' | 'gitee' | 'homepage';
declare class SocialInfo {
    content: string;
    name: SocialType;
    constructor(name: SocialType, content: string);
}
interface SocialLink {
    name: SocialType;
    link: string;
}

/**
 * @see [Web Manifest Categories]https://developer.mozilla.org/en-US/docs/Web/Manifest/categories
 * @see [W3C Categories](https://github.com/w3c/manifest/wiki/Categories)
 */
type Category = 'news' | 'photo' | 'productivity' | 'social' | 'utilities' | 'weather' | 'calendar' | 'countdown' | 'fun' | 'time';

interface IWidgetOptions extends IWindowSize, IPageOptions {
    supportDeployMode?: DeployMode;
    configPagePath?: string;
    /**
     * 如果为true，组件将不会添加到组件包中
     */
    disabled?: boolean;
    previewImage: string;
    categories?: Category[];
    /**
     * 组件包所需的App版本
     */
    requiredAppVersion?: string;
    description: LanguageTextMap;
    keywords: WidgetKeyword[];
    /**
     * @deprecated
     */
    routes?: WidgetRoute[];
    /**
     * 一般用于填写教程链接
     */
    socialLinks?: SocialLink[];
}
interface IBackgroundWidgetOptions extends Omit<IWidgetOptions, 'width' | 'height'> {
    width?: number;
    height?: number;
    browserWindowOptions?: BrowserWindowOptions;
}
/**
 * @deprecated
 */
interface WidgetRoute {
    url: string;
    name: string;
}
declare class Widget extends Page {
    readonly previewImage: string;
    readonly categories?: Category[];
    readonly supportDeployMode: number;
    /**
     * 组件包所需的App版本
     */
    readonly requiredAppVersion?: string;
    /**
     * 如果为true，组件将不会添加到组件包中
     */
    readonly disabled?: boolean;
    /**
     * 配置页面路径，没有则不能修改
     */
    readonly configPagePath?: string;
    /**
     * @deprecated
     */
    readonly routes: WidgetRoute[];
    protected browserWindowOptions?: BrowserWindowOptions;
    readonly socialLinks?: SocialLink[];
    constructor(options: IWidgetOptions);
    static parseJSON(json: string): Widget;
    static parseObject(obj: any): Widget;
    /**
     * 是否支持悬浮窗
     */
    isSupportOverlap(): boolean;
    isSupportBackground(): boolean;
    /**
     * 是否支持普通模式
     */
    isSupportNormal(): boolean;
    isConfigurable(): boolean;
}
declare class BackgroundWidget extends Widget {
    constructor(options: IBackgroundWidgetOptions);
}
declare enum WidgetKeyword {
    RECOMMEND = "recommend",
    TOOLS = "tools",
    EFFICIENCY = "efficiency",
    PICTURE = "picture",
    LIFE = "life",
    SHORTCUT = "shortcut",
    COUNTDOWN = "countdown",
    TIMER = "timer",
    INFO = "info",
    DASHBOARD = "dashboard"
}

declare enum WebSocketEventType {
    RESISTER_PACKAGE = "ws::cn.widgetjs.core.resister_package"
}
declare class WebSocketEvent {
    type: WebSocketEventType;
    payload: any;
    constructor(type: WebSocketEventType, payload: any);
}

interface NativeKeyboardEvent {
    name: string;
    keyCode: number;
    scanCode: number;
    isKeyUp: boolean;
}

interface AppMouseEvent {
    handled: boolean;
    wheelScrolled: boolean;
    clicked: boolean;
    isMouseButtonDown: boolean;
    isMouseButtonUp: boolean;
    timestamp: number;
    button: number;
    clicks: number;
    x: number;
    y: number;
    delta: number;
    location: string;
}

declare class ElectronUtils {
    static hasElectronApi(): boolean;
    /**
     * 获取ElectronAPI
     * windows api
     */
    static getAPI(): any;
    static invokeMethod(channel: string, method: string, ...args: any[]): Promise<any>;
    static invoke(channel: string, ...args: any[]): Promise<any>;
}

declare class LanguageUtils {
    static findText(langMap: LanguageTextMap, localeCode: LanguageCode): Intl.Locale | undefined;
    /**
     * Get text from `LanguageTextMap` by Unicode locale identifier.
     * `localeCode` > `localeCode` without region > browser default language > English > first language
     * @param langMap       对象
     * @param {LanguageCode} localeCode  `zh-CN`、`en-US`、 `zh`、`en`
     * @param fallbackToBrowser
     */
    static getTextByLocate(langMap: LanguageTextMap, localeCode?: LanguageCode, fallbackToBrowser?: boolean): string | undefined;
}

declare class WidgetUtils {
    /**
     * 是否支持悬浮窗
     */
    static isSupportOverlap(supportDeployMode: number): boolean;
    static isSupportBackground(supportDeployMode: number): boolean;
    /**
     * 是否支持普通模式
     */
    static isSupportNormal(supportDeployMode: number): boolean;
    static isConfigurable(configPagePath: string): boolean;
}

declare function delay(ms: number): Promise<unknown>;

declare class WidgetPackageUtils {
    static getRemotePackageJsonUrl(remoteInfo: RemotePackageUrlInfo): string | undefined;
    static getRemoteEntryUrl(remoteInfo: RemotePackageUrlInfo): string | undefined;
}

/**
 * Possible values in normalized {@link LocationQuery}. `null` renders the query
 * param but without an `=`.
 *
 * @example
 * ```
 * ?isNull&isEmpty=&other=other
 * gives
 * `{ isNull: null, isEmpty: '', other: 'other' }`.
 * ```
 *
 * @internal
 */
type LocationQueryValue = string | null;
/**
 * Possible values when defining a query.
 *
 * @internal
 */
type LocationQueryValueRaw = LocationQueryValue | number | undefined;
/**
 * Normalized query object that appears in {@link RouteLocationNormalized}
 *
 * @public
 */
type LocationQuery = Record<string, LocationQueryValue | LocationQueryValue[]>;
/**
 * Loose {@link LocationQuery} object that can be passed to functions like
 * {@link Router.push} and {@link Router.replace} or anywhere when creating a
 * {@link RouteLocationRaw}
 *
 * @public
 */
type LocationQueryRaw = Record<string | number, LocationQueryValueRaw | LocationQueryValueRaw[]>;
/**
 * Transforms a queryString into a {@link LocationQuery} object. Accept both, a
 * version with the leading `?` and without Should work as URLSearchParams
 * @internal
 *
 * @param search - search string to parse
 * @returns a query object
 */
declare function parseQuery(search: string): LocationQuery;
/**
 * Stringifies a {@link LocationQueryRaw} object. Like `URLSearchParams`, it
 * doesn't prepend a `?`
 *
 * @internal
 *
 * @param query - query object to stringify
 * @returns string version of the query without the leading `?`
 */
declare function stringifyQuery(query: LocationQueryRaw): string;

interface NormalizeOptions {
    /**
     @default 'http'
     */
    defaultProtocol?: string | 'http' | 'https';
    /**
     Prepends `defaultProtocol` to the URL if it's protocol-relative.
  
     @default true
  
     @example
     ```
     normalizeUrl('//sindresorhus.com');
     //=> 'http://sindresorhus.com'
  
     normalizeUrl('//sindresorhus.com', {normalizeProtocol: false});
     //=> '//sindresorhus.com'
     ```
     */
    readonly normalizeProtocol?: boolean;
    /**
     Normalizes HTTPS URLs to HTTP.
  
     @default false
  
     @example
     ```
     normalizeUrl('https://sindresorhus.com');
     //=> 'https://sindresorhus.com'
  
     normalizeUrl('https://sindresorhus.com', {forceHttp: true});
     //=> 'http://sindresorhus.com'
     ```
     */
    readonly forceHttp?: boolean;
    /**
     Normalizes HTTP URLs to HTTPS.
  
     This option cannot be used with the `forceHttp` option at the same time.
  
     @default false
  
     @example
     ```
     normalizeUrl('http://sindresorhus.com');
     //=> 'http://sindresorhus.com'
  
     normalizeUrl('http://sindresorhus.com', {forceHttps: true});
     //=> 'https://sindresorhus.com'
     ```
     */
    readonly forceHttps?: boolean;
    /**
     Strip the [authentication](https://en.wikipedia.org/wiki/Basic_access_authentication) part of a URL.
  
     @default true
  
     @example
     ```
     normalizeUrl('https://user:password@sindresorhus.com');
     //=> 'https://sindresorhus.com'
  
     normalizeUrl('https://user:password@sindresorhus.com', {stripAuthentication: false});
     //=> 'https://user:password@sindresorhus.com'
     ```
     */
    readonly stripAuthentication?: boolean;
    /**
     Removes hash from the URL.
  
     @default false
  
     @example
     ```
     normalizeUrl('sindresorhus.com/about.html#contact');
     //=> 'http://sindresorhus.com/about.html#contact'
  
     normalizeUrl('sindresorhus.com/about.html#contact', {stripHash: true});
     //=> 'http://sindresorhus.com/about.html'
     ```
     */
    readonly stripHash?: boolean;
    /**
     Remove the protocol from the URL: `http://sindresorhus.com` → `sindresorhus.com`.
  
     It will only remove `https://` and `http://` protocols.
  
     @default false
  
     @example
     ```
     normalizeUrl('https://sindresorhus.com');
     //=> 'https://sindresorhus.com'
  
     normalizeUrl('sindresorhus.com', {stripProtocol: true});
     //=> 'sindresorhus.com'
     ```
     */
    readonly stripProtocol?: boolean;
    /**
     Strip the [text fragment](https://web.dev/text-fragments/) part of the URL
  
     __Note:__ The text fragment will always be removed if the `stripHash` option is set to `true`, as the hash contains the text fragment.
  
     @default true
  
     @example
     ```
     normalizeUrl('http://sindresorhus.com/about.html#:~:text=hello');
     //=> 'http://sindresorhus.com/about.html#'
  
     normalizeUrl('http://sindresorhus.com/about.html#section:~:text=hello');
     //=> 'http://sindresorhus.com/about.html#section'
  
     normalizeUrl('http://sindresorhus.com/about.html#:~:text=hello', {stripTextFragment: false});
     //=> 'http://sindresorhus.com/about.html#:~:text=hello'
  
     normalizeUrl('http://sindresorhus.com/about.html#section:~:text=hello', {stripTextFragment: false});
     //=> 'http://sindresorhus.com/about.html#section:~:text=hello'
     ```
     */
    readonly stripTextFragment?: boolean;
    /**
     Removes `www.` from the URL.
  
     @default true
  
     @example
     ```
     normalizeUrl('http://www.sindresorhus.com');
     //=> 'http://sindresorhus.com'
  
     normalizeUrl('http://www.sindresorhus.com', {stripWWW: false});
     //=> 'http://www.sindresorhus.com'
     ```
     */
    readonly stripWWW?: boolean;
    /**
     Removes query parameters that matches any of the provided strings or regexes.
  
     @default [/^utm_\w+/i]
  
     @example
     ```
     normalizeUrl('www.sindresorhus.com?foo=bar&ref=test_ref', {
        removeQueryParameters: ['ref']
      });
     //=> 'http://sindresorhus.com/?foo=bar'
     ```
  
     If a boolean is provided, `true` will remove all the query parameters.
  
     ```
     normalizeUrl('www.sindresorhus.com?foo=bar', {
        removeQueryParameters: true
      });
     //=> 'http://sindresorhus.com'
     ```
  
     `false` will not remove any query parameter.
  
     ```
     normalizeUrl('www.sindresorhus.com?foo=bar&utm_medium=test&ref=test_ref', {
        removeQueryParameters: false
      });
     //=> 'http://www.sindresorhus.com/?foo=bar&ref=test_ref&utm_medium=test'
     ```
     */
    readonly removeQueryParameters?: ReadonlyArray<RegExp | string> | boolean;
    /**
     Keeps only query parameters that matches any of the provided strings or regexes.
  
     __Note__: It overrides the `removeQueryParameters` option.
  
     @default undefined
  
     @example
     ```
     normalizeUrl('https://sindresorhus.com?foo=bar&ref=unicorn', {
        keepQueryParameters: ['ref']
      });
     //=> 'https://sindresorhus.com/?ref=unicorn'
     ```
     */
    readonly keepQueryParameters?: ReadonlyArray<RegExp | string>;
    /**
     Removes trailing slash.
  
     __Note__: Trailing slash is always removed if the URL doesn't have a pathname unless the `removeSingleSlash` option is set to `false`.
  
     @default true
  
     @example
     ```
     normalizeUrl('http://sindresorhus.com/redirect/');
     //=> 'http://sindresorhus.com/redirect'
  
     normalizeUrl('http://sindresorhus.com/redirect/', {removeTrailingSlash: false});
     //=> 'http://sindresorhus.com/redirect/'
  
     normalizeUrl('http://sindresorhus.com/', {removeTrailingSlash: false});
     //=> 'http://sindresorhus.com'
     ```
     */
    readonly removeTrailingSlash?: boolean;
    /**
     Remove a sole `/` pathname in the output. This option is independent of `removeTrailingSlash`.
  
     @default true
  
     @example
     ```
     normalizeUrl('https://sindresorhus.com/');
     //=> 'https://sindresorhus.com'
  
     normalizeUrl('https://sindresorhus.com/', {removeSingleSlash: false});
     //=> 'https://sindresorhus.com/'
     ```
     */
    readonly removeSingleSlash?: boolean;
    /**
     Removes the default directory index file from path that matches any of the provided strings or regexes.
     When `true`, the regex `/^index\.[a-z]+$/` is used.
  
     @default false
  
     @example
     ```
     normalizeUrl('www.sindresorhus.com/foo/default.php', {
        removeDirectoryIndex: [/^default\.[a-z]+$/]
      });
     //=> 'http://sindresorhus.com/foo'
     ```
     */
    removeDirectoryIndex?: boolean | ReadonlyArray<RegExp | string>;
    /**
     Removes an explicit port number from the URL.
  
     Port 443 is always removed from HTTPS URLs and 80 is always removed from HTTP URLs regardless of this option.
  
     @default false
  
     @example
     ```
     normalizeUrl('sindresorhus.com:123', {
        removeExplicitPort: true
      });
     //=> 'http://sindresorhus.com'
     ```
     */
    readonly removeExplicitPort?: boolean;
    /**
     Sorts the query parameters alphabetically by key.
  
     @default true
  
     @example
     ```
     normalizeUrl('www.sindresorhus.com?b=two&a=one&c=three', {
        sortQueryParameters: false
      });
     //=> 'http://sindresorhus.com/?b=two&a=one&c=three'
     ```
     */
    readonly sortQueryParameters?: boolean;
}
declare function normalizeUrl(urlString: string, options?: NormalizeOptions): string;

interface IGridRect {
    top: number;
    left: number;
    width: number;
    height: number;
}
declare class GridRect implements IGridRect {
    top: number;
    left: number;
    width: number;
    height: number;
    constructor(left: number, top: number, width: number, height: number);
    get right(): number;
    get bottom(): number;
}
declare class GridSystem extends GridRect {
    cellSize: number;
    horizontalCellCount: number;
    verticalCellCount: number;
    screenWidth: number;
    screenHeight: number;
    /**
     * 屏幕x坐标，用于解决多块屏幕坐标计算问题
     */
    screenLeft?: number;
    /**
     * 屏幕y坐标，用于解决多块屏幕坐标计算问题
     */
    screenTop?: number;
    canvasScreenTop: number;
    canvasScreenLeft: number;
    /**
     *
     * @param cellSize
     * @param padding     至少保留的边距
     * @param screenWidth
     * @param screenHeight
     * @param screenX
     * @param screenY
     */
    constructor(cellSize: number, padding: number, screenWidth: number, screenHeight: number, screenX?: number, screenY?: number);
    /**
     * 将坐标对齐到网格上
     * @param x
     * @param y
     * @param gridSystem
     */
    snapCanvasPosition(x: number, y: number): number[];
    private snapPosition;
    snapSize(width: number, height: number): number[];
    /**
     * 将矩形对齐到网格上
     * @param rect
     * @param minWidth
     * @param maxWidth
     * @param minHeight
     * @param maxHeight
     */
    snapCanvasRect(rect: GridRect, minWidth: number, maxWidth: number, minHeight: number, maxHeight: number): IGridRect;
    private snapRect;
    /**
     * 将矩形对齐到网格上，与snapRect的区别是，这个会加上屏幕x和y坐标，用于适配多个显示器
     * @param rect
     * @param minWidth
     * @param maxWidth
     * @param minHeight
     * @param maxHeight
     */
    snapWindow(rect: GridRect, minWidth: number, maxWidth: number, minHeight: number, maxHeight: number): IGridRect;
    /**
     * 限制值不超出屏幕
     * @param value
     * @param min
     * @param max
     * @private
     */
    private getRangeValue;
    getWidth(): number;
    getHeight(): number;
}

export { type AddWidgetOption, type AlignPosition, ApiConstants, AppApi, AppApiConstants, AppApiEvent, type AppApiMethods, type AppMouseEvent, AppNotification, AppReminderNotification, type AppRuntimeInfo, BackgroundWidget, BaseApi, type BatteryData, BroadcastApi, type BroadcastApiMethods, BroadcastEvent, type BroadcastEventType, BrowserWindowApi, BrowserWindowApiEvent, type BrowserWindowApiMethods, type BrowserWindowOptions, type CallNotificationOption, type Category, Channel, ClipboardApi, ClipboardApiEvent, type ClipboardApiMethods, type CountdownNotificationOption, type CpuCacheData, type CpuCurrentSpeedData, type CpuData, type CurrentLoadCpuData, type CurrentLoadData, DefaultWidgetTheme, DeployMode, DeployedPage, DeployedWidget, DeployedWidgetApi, type DeployedWidgetApiMethods, type DevOptions, DeviceApi, type DeviceApiMethods, DialogApi, type DialogApiMethods, type DiskLayoutData, type Display, type DownloadUrlOptions, ElectronApi, ElectronUtils, FileApi, type FileApiMethods, type FileInfo, type GraphicsControllerData, type GraphicsData, type GraphicsDisplayData, Gravity, GridRect, GridSystem, type Hardware, type HardwareSensor, type HardwareType, HostedMode, type IAppApi, type IBackgroundWidgetOptions, type IDialogApi, type IGridRect, type ILogApi, type IMouseApi, type IPage, type IPageOptions, type IProcessApi, type IWidgetDataApi, type IWidgetOptions, type IWidgetPackageApi, type IWidgetTheme, type IWindowSize, type InfoNotificationOption, type Language, type LanguageCode, LanguageMap, type LanguageTextMap, LanguageUtils, type LocalPackageUrlInfo, type LocationQuery, type LocationQueryRaw, type LocationQueryValue, type LocationQueryValueRaw, LogApi, type LogApiMethods, type MemData, type MemLayoutData, MenuApi, MenuApiEvent, type MenuApiMethods, type MetaInfo, type Metadata, MouseApi, MouseApiEvent, type MouseApiMethods, type NativeKeyboardEvent, type Node, type NormalizeOptions, NotificationApi, NotificationApiEvent, type NotificationApiMethods, type NotificationOption, NotificationSize, type NotificationType, type OsData, Page, type Point, type Position, ProcessApi, type ProcessApiMethods, type ProxyConfig, type ReadDirOptions, type Rectangle, type ReminderNotificationOption, type RemotePackageUrlInfo, type SaveWidgetOption, type SensorType, type SetPositionOptions, ShortcutApi, ShortcutApiEvent, type ShortcutApiMethods, type ShowMenuOption, type Size, type SmartData, SocialInfo, type SocialLink, type SocialType, StorageApi, type StorageApiMethods, StoreApi, type StoreApiMethods, SystemApi, SystemApiEvent, type SystemApiMethods, type SystemFile, ThemeMode, type UserData, type VersionData, WebSocketEvent, WebSocketEventType, Widget, WidgetApi, WidgetApiEvent, type WidgetApiMethods, WidgetData, WidgetDataApi, type WidgetDataApiMethods, WidgetKeyword, type WidgetMenuItem, WidgetPackage, WidgetPackageApi, WidgetPackageApiEvent, type WidgetPackageApiMethods, type WidgetPackageOptions, WidgetPackageUtils, WidgetParams, type WidgetPermission, type WidgetRoute, WidgetTheme, type WidgetThemeKey, type WidgetThemeProperty, WidgetUtils, delay, normalizeUrl, parseQuery, stringifyQuery };
